\name{beta.polyclass}
\alias{beta.polyclass}
\title{Polyclass: polychotomous regression and multiple classification}
\description{Produces a beta-plot for a \code{polyclass} object.  }
\usage{beta.polyclass(fit, which, xsp = 0.4, cex) }
\arguments{
\item{fit}{\code{polyclass} object, typically the result of \code{\link{polyclass}}.  }
\item{which}{which classes should be compared? Default is to compare all classes.  }
\item{xsp}{location of the vertical line to the left of the axis. Useful for making 
high quality, device dependent, graphics.  }
\item{cex}{character size. Default is whatever the present character size is. 
Useful for making high quality, device dependent, graphics. 
}
}
\value{
A beta plot. One line for each basis function. The left part of the plot 
indicates the basis function, the right half the relative location of the 
betas (coefficients) of that basis function, normalized with respect 
to parent basis functions, for all classes. The scaling is supposed 
to suggest a relative importance of the basis functions. This may 
suggest which basis functions are important for separating particular classes. 
}
\references{ Charles Kooperberg, Smarajit Bose, and  Charles J. Stone (1997). 
Polychotomous regression. \emph{Journal of the American Statistical
Association}, \bold{92}, 117--127.

Charles J. Stone, Mark Hansen, Charles Kooperberg, and Young K. Truong. 
The use of polynomial splines and their tensor products in extended
linear modeling (with discussion) (1997).  \emph{Annals of Statistics},
\bold{25}, 1371--1470.}
\author{ Charles Kooperberg \email{clk@fhcrc.org}.}
\seealso{ 
\code{\link{polyclass}},
\code{\link{plot.polyclass}}, 
\code{\link{summary.polyclass}}, 
\code{\link{cpolyclass}}, 
\code{\link{ppolyclass}}, 
\code{\link{rpolyclass}}.}
\note{This is not a generic function, and the complete name, beta.polyclass, has to
be specified.}
\examples{
data(iris)
fit.iris <- polyclass(iris[,5], iris[,1:4])
beta.polyclass(fit.iris)
}
\keyword{smooth}
\keyword{nonlinear}

\eof
\name{clspec}
\alias{clspec}
\alias{dlspec}
\alias{plspec}
\alias{rlspec}
\title{Lspec: logspline estimation of a spectral distribution}
\description{Autocorrelations, autocovariances
(\code{clspec}), spectral densities and line spectrum (\code{dlspec}),
spectral distributions (\code{plspec}) or a
random time series(\code{rlspec}) from a model fitted with \code{\link{lspec}}.}
\usage{clspec(lag, fit, cov = TRUE, mm) 
dlspec(freq, fit) 
plspec(freq, fit, mm) 
rlspec(n, fit, mean = 0, cosmodel = FALSE, mm)}
\arguments{
\item{lag}{ vector of integer-valued lags for which the  autocorrelations or autocorrelations are to be computed.  }
\item{fit}{ \code{lspec} object, typically the result of \code{\link{lspec}}.}
\item{cov}{ compute autocovariances (\code{TRUE}) or autocorrelations (\code{FALSE}).  }
\item{mm}{ number of points used in integration and the fft. Default is the 
smallest power of two larger than \code{max(fit\$sample, max(lag),1024)}  for
\code{clspec} and \code{plspec}
or the smallest power of two larger than \code{max(fit\$sample, n, max(lag),
1024)} for  (\code{rlspec}).  }
\item{freq}{ vector of frequencies. For \code{plspec} frequencies should be between \eqn{-\pi}{-pi} and \eqn{\pi}{pi}.  }
\item{n}{ length of the random time series to be generated.  }
\item{mean}{ mean level of the time series to be generated.  }
\item{cosmodel}{ indicate that the data should be generated from a model with constant 
harmonic terms rather than a true Gaussian time series.  }
}
\value{Autocovariances or autocorrelations (\code{clspec}); 
values of the spectral distribution at the requested frequencies. (\code{plspec}); 
random time series of length \code{n} (code{rlspec}); 
or a  list with three components  (code{dlspec}):
\item{d}{the  spectral density evaluated at the vector of frequencies,}
\item{modfreq}{modified frequencies of the form \eqn{\frac{2\pi j}{T}}{(2pi*j/T)} that are close to the 
frequencies that were requested,}
\item{m}{mass of the line spectrum at the modified frequencies.}
}
\references{ 
Charles Kooperberg, Charles J. Stone, and Young K. Truong (1995). 
Logspline Estimation of a Possibly Mixed Spectral Distribution.
\emph{Journal of Time Series Analysis}, \bold{16}, 359-388.

Charles J. Stone, Mark Hansen, Charles Kooperberg, and Young K. Truong. 
The use of polynomial splines and their tensor products in extended
linear modeling (with discussion) (1997).  \emph{Annals of Statistics},
\bold{25}, 1371--1470.}
\author{ Charles Kooperberg \email{clk@fhcrc.org}.}
\seealso{\code{\link{lspec}}, \code{\link{plot.lspec}}, \code{\link{summary.lspec}}.}
\examples{
data(co2)
co2.detrend <- lm(co2~c(1:length(co2)))$residuals
fit <- lspec(co2.detrend)
clspec(0:12,fit)
plspec((0:314)/100, fit)
dlspec((0:314)/100, fit)
rlspec(length(co2),fit)
}
\keyword{ts}
\keyword{smooth}

\eof
\name{cpolyclass}
\alias{cpolyclass}
\alias{ppolyclass}
\alias{rpolyclass}
\title{Polyclass: polychotomous regression and multiple classification}
\description{ Classify new cases (\code{cpolyclass}), compute class probabilities
for new cases (\code{ppolyclass}), and generate random multinomials for new cases
(\code{rpolyclass}) for a \code{\link{polyclass}} model.}
\usage{cpolyclass(cov, fit)
ppolyclass(data, cov, fit) 
rpolyclass(n, cov, fit) }
\arguments{
\item{cov}{ covariates. Should be a matrix with \code{fit\$ncov} columns.  
For \code{rpolyclass} \code{cov} should either have one row, in 
which case all random numbers are based on the same covariates, or \code{n} 
rows in which case each random number has its own covariates.  }
\item{fit}{ \code{polyclass} object, typically the result of \code{\link{polyclass}}. }
\item{data}{
there are several possibilities. If data is a vector with as many elements 
as cov has rows, each element of data corresponds to a row of cov; if 
only one value is given, the probability of being in that class is computed 
for all sets of covariates. If data is omitted, all class probabilities are 
provided. 
}
\item{n}{ number of pseudo random numbers to be generated.  }
}
\value{ Most likely classes (\code{cpolyclass}),
probabilities (\code{cpolyclass}), or
random classes according to the estimated probabilities (\code{rpolyclass}).
}
\references{ Charles Kooperberg, Smarajit Bose, and  Charles J. Stone (1997).
Polychotomous regression. \emph{Journal of the American Statistical
Association}, \bold{92}, 117--127.

Charles J. Stone, Mark Hansen, Charles Kooperberg, and Young K. Truong.
The use of polynomial splines and their tensor products in extended
linear modeling (with discussion) (1997).  \emph{Annals of Statistics},
\bold{25}, 1371--1470.}
\author{ Charles Kooperberg \email{clk@fhcrc.org}.}
\seealso{
\code{\link{polyclass}},
\code{\link{plot.polyclass}}, 
\code{\link{summary.polyclass}},
\code{\link{beta.polyclass}}.}   
\examples{
data(iris)
fit.iris <- polyclass(iris[,5], iris[,1:4])
class.iris <- cpolyclass(iris[,1:4], fit.iris)
table(class.iris, iris[,5])
prob.setosa <- ppolyclass(1, iris[,1:4], fit.iris)
prob.correct <- ppolyclass(iris[,5], iris[,1:4], fit.iris) 
rpolyclass(100, iris[64,1:4], fit.iris)
}
\keyword{smooth}
\keyword{nonlinear}

\eof
\name{dhare}
\alias{dhare}
\alias{hhare}
\alias{phare}
\alias{qhare}
\alias{rhare}
\title{Hare: hazard regression}
\description{Density (\code{dhare}), cumulative probability (\code{phare}), hazard rate (\code{hhare}), quantiles
(\code{qhare}), and  random samples (\code{rhare}) from 
a \code{\link{hare}} object.}
\usage{dhare(q, cov, fit) 
hhare(q, cov, fit) 
phare(q, cov, fit) 
qhare(p, cov, fit) 
rhare(n, cov, fit) }
\arguments{
\item{q}{ vector of quantiles. Missing values (\code{NA}s) are allowed.  }
\item{p}{ vector of probabilities. Missing values (\code{NA}s) are allowed.  }
\item{n}{
sample size. If \code{length(n)} is larger than 1, then 
\code{length(n)} random values are returned. 
}
\item{cov}{
covariates. There are several possibilities. If a vector of length 
\code{fit\$ncov} is provided, these covariates are used for all elements of \code{p} or 
\code{q} or for all random numbers. If a matrix of dimension \code{length(p)},
\code{length(q)}, or \code{n} by \code{fit\$ncov} is provided, the rows of \code{cov} are 
matched with the elements of \code{p} or \code{q} or every row of \code{cov} has its own 
random number. If a matrix of dimension \code{m} times \code{fit\$ncov} is provided, 
while \code{length(p) = 1} or \code{length(q) = 1} or \code{n = 1}, the single element of \code{p} or \code{q} is 
used \code{m} times, or \code{m} random numbers with different sets of covariates are 
generated. 
}
\item{fit}{ \code{hare} object, typically obtained from \code{\link{hare}}.  }
}
\value{Densities (\code{dhare}), hazard rates (\code{hhare}), 
probabilities (\code{phare}), quantiles (\code{qhare}), 
or a random sample (\code{rhare}) from a \code{\link{hare}} object.}
}
\details{
Elements of \code{q} or \code{p} that are missing will cause the 
corresponding elements of the result to be missing. 
}
\references{Charles Kooperberg, Charles J. Stone and Young K. Truong (1995). 
Hazard regression.  \emph{Journal of the American Statistical
Association}, \bold{90}, 78-94.

Charles J. Stone, Mark Hansen, Charles Kooperberg, and Young K. Truong. 
The use of polynomial splines and their tensor products in extended
linear modeling (with discussion) (1997).  \emph{Annals of Statistics},
\bold{25}, 1371--1470.}
\author{ Charles Kooperberg \email{clk@fhcrc.org}.}
\seealso{\code{\link{hare}},
\code{\link{plot.hare}},
\code{\link{summary.hare}}.}
\examples{
fit <- hare(testhare[,1], testhare[,2], testhare[,3:8])
dhare(0:10, testhare[117,3:8], fit)
hhare(0:10, testhare[1:11,3:8], fit)
phare(10, testhare[1:25,3:8], fit)
qhare((1:19)/20, testhare[117,3:8], fit)
rhare(10, testhare[117,3:8], fit)
}
\keyword{distribution}
\keyword{smooth}
\keyword{survival}

\eof
\name{dheft}
\alias{dheft}
\alias{hheft}
\alias{pheft}
\alias{qheft}
\alias{rheft}
\title{Heft: hazard estimation with flexible tails}
\description{Density (\code{dheft}), cumulative probability (\code{pheft}), hazard rate (\code{hheft}),
quantiles (\code{qheft}), and  random samples (\code{rheft}) from a \code{\link{heft}} object}
\usage{dheft(q, fit) 
hheft(q, fit) 
pheft(q, fit) 
qheft(p, fit) 
rheft(n, fit) }
\arguments{
\item{q}{ vector of quantiles. Missing values (\code{NA}s) are allowed.  }
\item{p}{ vector of probabilities. Missing values (\code{NA}s) are allowed.  }
\item{n}{
sample size. If \code{length(n)} is larger than 1, then
\code{length(n)} random values are returned.
}
\item{fit}{
 \code{heft} object, typically obtained from \code{\link{heft}}.  }
}
}
\value{Densities (\code{dheft}), hazard rates (\code{hheft}),
probabilities (\code{pheft}), quantiles (\code{qheft}),
or a random sample (\code{rheft}) from a \code{\link{heft}} object.}
}
\details{
Elements of \code{q} or \code{p} that are missing will cause the
corresponding elements of the result to be missing.
}
\references{Charles Kooperberg, Charles J. Stone and Young K. Truong (1995).
Hazard regression.  \emph{Journal of the American Statistical
Association}, \bold{90}, 78-94.

Charles J. Stone, Mark Hansen, Charles Kooperberg, and Young K. Truong.
The use of polynomial splines and their tensor products in extended
linear modeling (with discussion) (1997).  \emph{Annals of Statistics},
\bold{25}, 1371--1470.}
\author{ Charles Kooperberg \email{clk@fhcrc.org}.}
\seealso{ \code{\link{heft}}, \code{\link{plot.heft}}, \code{\link{summary.heft}}.  }
\examples{
fit <- heft(testhare[,1],testhare[,2])
dheft(0:10,fit)
hheft(0:10,fit)
pheft(0:10,fit)
qheft((1:19)/20,fit)
rheft(10,fit)
}
\keyword{distribution}
\keyword{smooth}
\keyword{survival}

\eof
\name{dlogspline}
\alias{dlogspline}
\alias{plogspline}
\alias{qlogspline}
\alias{rlogspline}
\title{Logspline Density Estimation}
\description{Density (\code{dlogspline}), cumulative probability (\code{plogspline}), quantiles
(\code{qlogspline}), and  random samples (\code{rlogspline}) from 
a logspline density that was fitted using
the 1997 knot addition and deletion algorithm (\code{\link{logspline}}). 
The 1992 algorithm is available using the \code{\link{oldlogspline}} function.
}
\usage{dlogspline(q, fit) 
plogspline(q, fit) 
qlogspline(p, fit) 
rlogspline(n, fit) }
\arguments{
\item{q}{
vector of quantiles. Missing values (NAs) are allowed. 
}
\item{p}{
vector of probabilities. Missing values (NAs) are allowed. 
}
\item{n}{
sample size. If \code{length(n)} is larger than 1, then 
\code{length(n)} random values are returned.
}
\item{fit}{
\code{logspline} object, typically the result of \code{\link{logspline}}.
}
}
\value{Densities (\code{dlogspline}), probabilities (\code{plogspline}), quantiles (\code{qlogspline}), 
or a random sample (\code{rlogspline}) from a \code{logspline} density that was fitted using
knot addition and deletion.
}
\details{
Elements of \code{q} or \code{p} that are missing will cause the 
corresponding elements of the result to be missing. 
}
\references{Charles Kooperberg and Charles J. Stone.  Logspline density estimation
for censored data (1992). \emph{Journal of Computational and Graphical
Statistics}, \bold{1}, 301--328.

Charles J. Stone, Mark Hansen, Charles Kooperberg, and Young K. Truong. 
The use of polynomial splines and their tensor products in extended
linear modeling (with discussion) (1997).  \emph{Annals of Statistics},
\bold{25}, 1371--1470.}
\author{ Charles Kooperberg \email{clk@fhcrc.org}.}
\seealso{ 
\code{\link{logspline}},      
\code{\link{plot.logspline}},
\code{\link{summary.logspline}},
\code{\link{oldlogspline}}.}
\examples{
x <- rnorm(100)
fit <- logspline(x)
qq <- qlogspline((1:99)/100, fit)
plot(qnorm((1:99)/100), qq)                  # qq plot of the fitted density
pp <- plogspline((-250:250)/100, fit)
plot((-250:250)/100, pp, type = "l")
lines((-250:250)/100,pnorm((-250:250)/100))  # asses the fit of the distribution
dd <- dlogspline((-250:250)/100, fit)
plot((-250:250)/100, dd, type = "l")
lines((-250:250)/100, dnorm((-250:250)/100)) # asses the fit of the density
rr <- rlogspline(100, fit)                   # random sample from fit
}
\keyword{distribution}
\keyword{smooth}

\eof
\name{doldlogspline}
\alias{doldlogspline}
\alias{poldlogspline}
\alias{qoldlogspline}
\alias{roldlogspline}
\title{Logspline Density Estimation - 1992 version }
\description{Probability density function (\code{doldlogspline}), distribution
function (\code{poldlogspline}), quantiles 
(\code{qoldlogspline}), and  random samples (\code{roldlogspline}) from
a logspline density that was fitted using
the 1992 knot deletion algorithm (\code{\link{oldlogspline}}). 
The 1997 algorithm using knot
deletion and addition is available using the \code{\link{logspline}} function.
}
\usage{doldlogspline(q, fit) 
poldlogspline(q, fit) 
qoldlogspline(p, fit) 
roldlogspline(n, fit) }
\arguments{
\item{q}{
vector of quantiles. Missing values (NAs) are allowed. 
}
\item{p}{
vector of probabilities. Missing values (NAs) are allowed. 
}
\item{n}{
sample size. If \code{length(n)} is larger than 1, then 
\code{length(n)} random values are returned.
}
\item{fit}{
\code{oldlogspline} object, typically the result of \code{\link{oldlogspline}}.
}
}
\value{ Densities (\code{doldlogspline}), probabilities (\code{poldlogspline}), quantiles (\code{qoldlogspline}), 
or a random sample (\code{roldlogspline})
from an \code{oldlogspline} density that was fitted using
knot deletion.
}
\details{
Elements of  \code{q} or \code{p} that are missing will cause the 
corresponding elements of the result to be missing. 
}
\references{Charles Kooperberg and Charles J. Stone.  Logspline density estimation
for censored data (1992). \emph{Journal of Computational and Graphical
Statistics}, \bold{1}, 301--328.

Charles J. Stone, Mark Hansen, Charles Kooperberg, and Young K. Truong.
The use of polynomial splines and their tensor products in extended
linear modeling (with discussion) (1997).  \emph{Annals of Statistics},
\bold{25}, 1371--1470.}
\author{ Charles Kooperberg \email{clk@fhcrc.org}.}
\seealso{
\code{\link{logspline}},
\code{\link{oldlogspline}},
\code{\link{plot.oldlogspline}},
\code{\link{summary.oldlogspline}}}
\examples{
x <- rnorm(100)
fit <- oldlogspline(x)
qq <- qoldlogspline((1:99)/100, fit)
plot(qnorm((1:99)/100), qq)                  # qq plot of the fitted density
pp <- poldlogspline((-250:250)/100, fit)
plot((-250:250)/100, pp, type = "l")
lines((-250:250)/100, pnorm((-250:250)/100)) # asses the fit of the distribution
dd <- doldlogspline((-250:250)/100, fit)
plot((-250:250)/100, dd, type = "l")
lines((-250:250)/100, dnorm((-250:250)/100)) # asses the fit of the density
rr <- roldlogspline(100, fit)                # random sample from fit
}
\keyword{distribution}
\keyword{smooth}

\eof
\name{hare}
\alias{hare}
\title{Hare: hazard regression}
\description{Fit a hazard regression model: linear splines are used to model
the baseline hazard, covariates, and interactions. Fitted models
can be, but do not need to be, proportional hazards models.
}
\usage{hare(data, delta, cov, penalty, maxdim, exclude, include, prophaz = FALSE,
additive = FALSE, linear, fit, silent = TRUE) 
}
\arguments{
\item{data}{
vector of observations. Observations may or may not be right censored. All 
observations should be nonnegative. 
}
\item{delta}{
binary vector with the same length as \code{data}. Elements of \code{data} 
for which the corresponding element of \code{delta} is 0 are assumed to be 
right censored, elements of \code{data} 
for which the corresponding element of \code{delta} is 1 are assumed to be 
uncensored. If \code{delta} is missing, all observations are assumed to be uncensored. 
}
\item{cov}{
covariates: matrix with as many rows as the length of \code{data}. May be omitted 
if there are no covariates. (If there are no covariates, however,
\code{\link{heft}} will provide a more flexible model using cubic splines.)
}
\item{penalty}{
the parameter to be used in the AIC criterion. The method chooses 
the number of knots that minimizes \code{-2 * loglikelihood + penalty * (dimension)}. 
The default is to use \code{penalty = log(samplesize)} as in BIC. The effect of 
this parameter is summarized in \code{\link{summary.hare}}. 
}
\item{maxdim}{
maximum dimension (default is \eqn{6*\mbox{length(data)}^0.2)}{\code{6 * length(data)^0.2}}. 
}
\item{exclude}{
combinations to be excluded - this should be a matrix with 2 
columns - if for example \code{exclude[1, 1] = 2} and \code{exclude[1, 2] = 3} no 
interaction between covariate 2 and 3 is included. 0 represents time. 
}
\item{include}{
those combinations that can be included. Should have the same format 
as \code{exclude}. Only one of \code{exclude} and \code{include} can be specified .
}
\item{prophaz}{ should the model selection be restricted to proportional hazards models?  }
\item{additive}{ should the model selection be restricted to additive models?  }
\item{linear}{
vector indicating for which of the variables no knots should 
be entered. For example, if \code{linear = c(2, 3)} no knots for either covariate 
2 or 3 are entered. 0 represents time. The default is none.
}
\item{fit}{
\code{\link{hare}} object. If  \code{fit} is specified, \code{\link{hare}} adds 
basis functions starting with those in \code{fit}. 
}
\item{silent}{
suppresses the printing of diagnostic output about basis functions added 
or deleted, Rao-statistics, Wald-statistics and log-likelihoods. 
}
}
\value{An object of class
\code{hare}, which is organized to serve as input for \code{\link{plot.hare}}, 
\code{\link{summary.hare}}, \code{\link{dhare}} (conditional density), \code{\link{hhare}}
(conditional hazard rate), \code{\link{phare}} (conditional probabilities), \code{\link{qhare}}
(conditional quantiles), and \code{\link{rhare}} (random numbers). 
The object is a list with the following members: 
\item{ncov}{ number of covariates.  }
\item{ndim}{ number of dimensions of the fitted model.  }
\item{fcts}{ matrix of size \code{ndim x 6}. each row is a basis function. 
First element: first covariate involved (0 means time); 

second element: which knot (0 means: constant (time) or linear (covariate)); 

third element: second covariate involved (\code{NA} means: this is a function of one variable); 

fourth element: knot involved (if the third element is \code{NA}, of no relevance); 

fifth element: beta; 

sixth element: standard error of beta.}
\item{knots}{
a matrix with \code{ncov} rows.
Covariate \code{i} has row \code{i+1}, time has row 1. 
First column: number of knots in this dimension;
other columns: the knots, appended with \code{NA}s to make it a matrix.
}
\item{penalty}{ the parameter used in the AIC criterion.}
\item{max}{ maximum element of survival data.}
\item{ranges}{ column \code{i} gives the range of the \code{i}-th covariate.}
\item{logl}{
matrix with two columns. The \code{i}-th element of the first column  
is the loglikelihood of the model of dimension \code{i}. The second column indicates whether this 
model was fitted during the addition stage (1) or during the deletion stage (0). 
}
\item{sample}{ sample size.}
}
\references{Charles Kooperberg, Charles J. Stone and Young K. Truong (1995).
Hazard regression.  \emph{Journal of the American Statistical
Association}, \bold{90}, 78-94.

Charles J. Stone, Mark Hansen, Charles Kooperberg, and Young K. Truong.
The use of polynomial splines and their tensor products in extended
linear modeling (with discussion) (1997).  \emph{Annals of Statistics},
\bold{25}, 1371--1470.}
\author{ Charles Kooperberg \email{clk@fhcrc.org}.}
\seealso{\code{\link{heft}},
\code{\link{plot.hare}},
\code{\link{summary.hare}},
\code{\link{dhare}},
\code{\link{hhare}},
\code{\link{phare}},
\code{\link{qhare}},
\code{\link{rhare}}.}
\examples{
fit <- hare(testhare[,1], testhare[,2], testhare[,3:8]) 
}
\keyword{distribution}
\keyword{smooth}
\keyword{survival}

\eof
\name{heft}
\alias{heft}
\title{Heft: hazard estimation with flexible tails}
\description{Hazard estimation using cubic splines to 
approximate the log-hazard function and special functions to allow
non-polynomial shapes in both tails. 
}
\usage{heft(data, delta, penalty, knots, leftlin, shift, leftlog,
rightlog, maxknots, mindist, silent = TRUE) }
\arguments{
\item{data}{
vector of observations. Observations may or may not be right censored. All
observations should be nonnegative.
}
\item{delta}{
binary vector with the same length as \code{data}. Elements of \code{data}
for which the corresponding element of \code{delta} is 0 are assumed to be
right censored, elements of \code{data}
for which the corresponding element of \code{delta} is 1 are assumed to be
uncensored. If \code{delta} is missing, all observations are assumed to be uncensored.
}
\item{penalty}{
the parameter to be used in the AIC criterion. The method chooses
the number of knots that minimizes \code{-2 * loglikelihood + penalty * (dimension)}.
The default is to use \code{penalty = log(samplesize)} as in BIC. The effect of
this parameter is summarized in \code{\link{summary.heft}}.
}
\item{knots}{
ordered vector of values, which forces the method to start with these knots. 
If \code{knots} is not specified, a default knot-placement rule is employed. 
}
\item{leftlin}{
if \code{leftlin} is \code{TRUE} an extra basis-function, which is linear to the left 
of the first knot, is included in the basis. 
If any of \code{data} is exactly 0, the default of \code{leftlin} is \code{TRUE},
otherwise it is \code{FALSE}.
}
\item{shift}{
parameter for the log terms. Default is \code{quantile(data[delta == 1], .75)}. 
}
\item{leftlog}{
coefficient of \eqn{\log \frac x{x + \mbox{shift}}}{\code{log(x/(x+shift))}}, which must be greater than 
\code{-1}. 
(In particular, if \code{leftlog} equals zero no 
\eqn{\log \frac x{x + \mbox{shift}}}{\code{log(x/(x+shift))}} term 
is included.) If \code{leftlog} is missing its maximum likelihood estimate is used. 
If any of \code{data} is exactly zero, \code{leftlog} is  
set to zero. 
}
\item{rightlog}{
coefficient of \eqn{\log (x + \mbox{shift})}{\code{log(x+shift)}}, which must be greater than 
\code{-1}.
(In particular, if \code{leftlog} equals zero no  
\eqn{\log (x + \mbox{shift})}{\code{log(x+shift)}} term
is included.)
If \code{rightlog} is missing its maximum likelihood estimate is used. 
}
\item{maxknots}{
maximum number of knots allowed in the model (default is 
\eqn{4*n^{0.2})}{\code{4 * n^0.2}}, where \eqn{n} is the length of
\code{data}.
}
\item{mindist}{ minimum distance in order statistics between knots. The
default is 5.  }
\item{silent}{
suppresses the printing of diagnostic output about knots added or deleted, 
Rao-statistics, Wald-statistics and log-likelihoods. 
}
}
\value{An object of class
\code{heft}, which is organized to serve as input for \code{\link{plot.heft}},
\code{\link{summary.heft}}, \code{\link{dheft}} (density), \code{\link{hheft}}
(hazard rate), \code{\link{pheft}} (probabilities), \code{\link{qheft}}
(quantiles), and \code{\link{rheft}} (random numbers).
The object is a list with the following members:
\item{knots }{
vector of the locations of the knots in the \code{heft} model. 
}
\item{logl}{
the \code{k}-th element is the log-likelihood of the fit with \code{k} knots. 
}
\item{thetak}{
coefficients of the knot part of the 
spline. The k-th coefficient is the coefficient 
of  \eqn{(x-t(k))^3_+}. If a coefficient is zero the corresponding 
knot was considered and then deleted from the model. 
}
\item{thetap}{
coefficients of the polynomial part of the spline. 
The first element is the constant term and 
the second element is the linear term. 
}
\item{thetal}{
coefficients of the logarithmic terms. The first element equals 
\code{leftlog} and the second element equals \code{rightlog}. 
}
\item{penalty}{
the penalty that was used. 
}
\item{shift}{ parameter used in the definition of the log terms.  }
\item{sample}{ the sample size.  }
\item{logse}{ the standard errors of \code{thetal}.  }
\item{max}{ the largest element of data.  }
\item{ad}{ vector indicating whether a model of this dimension 
was not fit (2), fit during the addition stage (0) or during 
the deletion stage (1).  }
}
\references{Charles Kooperberg, Charles J. Stone and Young K. Truong (1995).
Hazard regression.  \emph{Journal of the American Statistical
Association}, \bold{90}, 78-94.

Charles J. Stone, Mark Hansen, Charles Kooperberg, and Young K. Truong.
The use of polynomial splines and their tensor products in extended
linear modeling (with discussion) (1997).  \emph{Annals of Statistics},
\bold{25}, 1371--1470.}
\author{ Charles Kooperberg \email{clk@fhcrc.org}.}
\seealso{
\code{\link{hare}},
\code{\link{plot.heft}},
\code{\link{summary.heft}},
\code{\link{dheft}},
\code{\link{hheft}},
\code{\link{pheft}},
\code{\link{qheft}},
\code{\link{rheft}}.}
\examples{
fit1 <- heft(testhare[,1], testhare[,2])
# modify tail behavior
fit2 <- heft(testhare[,1], testhare[,2], leftlog = FALSE, rightlog = FALSE, 
          leftlin = TRUE)   
fit3 <- heft(testhare[,1], testhare[,2], penalty = 0)   # select largest model
}
\keyword{distribution}
\keyword{smooth}
\keyword{survival}

\eof
\name{logspline}
\alias{logspline}
\title{ Logspline Density Estimation }
\description{Fits a \code{logspline} density using splines to approximate the log-density
using 
the 1997 knot addition and deletion algorithm (\code{\link{logspline}}). 
The 1992 algorithm is available using the \code{\link{oldlogspline}} function.
}
\usage{logspline(x, lbound, ubound, maxknots = 0, knots, nknots = 0, penalty,
silent = TRUE, mind = -1) }
\arguments{
\item{x}{ data vector. The data needs to be uncensored. \code{\link{oldlogspline}}
can deal with right- left- and interval-censored data.  }
\item{lbound,ubound}{
lower/upper bound for the support of the density. For example, if there 
is a priori knowledge that the density equals zero to the left of 0, 
and has a discontinuity at 0, 
the user could specify \code{lbound = 0}. However, if the density is  
essentially zero near 0, one does not need to specify \code{lbound}. 
}
\item{maxknots}{
the maximum number of knots. The routine stops adding knots 
when this number of knots is reached. 
The method has an automatic rule 
for selecting maxknots if this parameter is not specified. 
}
\item{knots}{
ordered vector of values (that should cover the complete range of the 
observations), which forces the method to start with these knots. 
Overrules knots.	 
If \code{knots} is not specified, a default knot-placement rule is employed. 
}
\item{nknots}{
forces the method to start with \code{nknots} knots. 
The method has an automatic rule 
for selecting \code{nknots} if this parameter is not specified. 
}
\item{penalty}{
the parameter to be used in the AIC criterion. The method chooses 
the number of knots that minimizes
\code{-2 * loglikelihood + penalty * (number of knots - 1)}. 
The default 
is to use a penalty parameter of \code{penalty = log(samplesize)} as in BIC. The effect of 
this parameter is summarized in \code{\link{summary.logspline}}. 
}
\item{silent}{
should diagnostic output be printed? 
}
\item{mind}{
minimum distance, in order statistics, between knots. 
}
}
\value{Object of the class \code{logspline}, that is intended as input for
\code{\link{plot.logspline}} (summary plots), 
\code{\link{summary.logspline}} (fitting summary), 
\code{\link{dlogspline}} (densities), 
\code{\link{plogspline}} (probabilities),
\code{\link{qlogspline}} (quantiles),
\code{\link{rlogspline}} (random numbers from the fitted distribution).

The object has the following members: 

\item{call}{the command that was executed.}
\item{nknots}{the number of knots in the model that was selected.}
\item{coef.pol}{coefficients of the polynomial part of the spline.
The first coefficient is the constant term and
the second is the linear term.}
\item{coef.kts}{coefficients of the knots  part of the spline.
 The \code{k}-th element is the coefficient 
of \eqn{(x-t(k))^3_+} (where \eqn{x^3_+} means the positive part of the third power
of \eqn{x}, 
and \eqn{t(k)} means knot \code{k}).}
\item{knots}{vector of the locations of the knots in the \code{logspline} model.}
\item{maxknots}{the largest number of knots minus one considered during fitting
(i.e. with \code{maxknots = 6} the maximum number of knots is 5).}
\item{penalty}{the penalty that was used.  }
\item{bound}{
first element: 0 - \code{lbound} was \eqn{-\inf}{-infinity,} 1 it was something else; second 
element: \code{lbound}, if specified; third element: 0 - \code{ubound} was \eqn{\inf}{infinity}, 
1 it was something else; fourth element: \code{ubound}, if specified. 
}
\item{samples}{the sample size.}
\item{logl}
{matrix with 3 columns. Column one: number of knots; column two:
model fitted during addition (1) or deletion (2); column 3: log-likelihood.}
\item{range}{range of the input data.}
\item{mind}{minimum distance in order statistics between knots required during fitting
(the actual minimum distance may be much larger).}
}
\references{Charles Kooperberg and Charles J. Stone.  Logspline density estimation
for censored data (1992). \emph{Journal of Computational and Graphical
Statistics}, \bold{1}, 301--328.

Charles J. Stone, Mark Hansen, Charles Kooperberg, and Young K. Truong.
The use of polynomial splines and their tensor products in extended
linear modeling (with discussion) (1997).  \emph{Annals of Statistics},
\bold{25}, 1371--1470.}
\author{ Charles Kooperberg \email{clk@fhcrc.org}.}
\seealso{ 
\code{\link{plot.logspline}}, 
\code{\link{summary.logspline}},
\code{\link{dlogspline}}, 
\code{\link{plogspline}},
\code{\link{qlogspline}}, \cr
\code{\link{rlogspline}},
\code{\link{oldlogspline}}.}
\examples{
y <- rnorm(100)
fit <- logspline(y)       
plot(fit)
# as (4 == length(-2, -1, 0, 1, 2) -1), this forces these initial knots,
# and does no knot selection
fit <- logspline(y, knots = c(-2, -1, 0, 1, 2), maxknots = 4, penalty = 0)  
}
\keyword{distribution}
\keyword{smooth}

\eof
\name{lspec}
\alias{lspec}
\title{Lspec: logspline estimation of a spectral distribution}
\description{ Fit an \code{lspec} model
to a time-series or a periodogram.}
\usage{lspec(data, period, penalty, minmass, knots, maxknots, atoms, maxatoms,
maxdim , odd = FALSE, updown = 3, silent = TRUE) }
\arguments{
\item{data}{
time series (exactly one of \code{data} and \code{period} should be specified). 
If \code{data} is specified, \code{lspec} first computes the modulus 
of the fast Fourier transform 
of the series using the function
\code{\link{fft}}, resulting in a periodogram of length
\code{floor(length(data)/2)}. 
}
\item{period}{
value of the periodogram for a time series at frequencies 
\eqn{\frac{2\pi j}T}{2pi*j/T}, for \eqn{1\leq j \leq T/2}{1<=j<=T/2}. If period is specified, odd should indicate 
whether the length of the series T is odd \code{(odd = TRUE)} or even \code{(odd = FALSE)}. 
Exactly one of \code{data} and \code{period} should be specified. 
}
\item{penalty}{
the parameter to be used in the AIC criterion. The method chooses 
the number of basis 
functions that minimizes \code{-2 * loglikelihood + penalty * (number of basis 
functions)}. 
Default is to use a penalty parameter of \code{penalty = log(length(period))} as in BIC.  }
\item{minmass}{
threshold value for atoms. No atoms having smaller mass than \code{minmass} are 
included in the model. If \code{minmass} takes its default value, in 
95\% of the samples, when data is Gaussian white noise, the model will not 
contain atoms.  }
\item{knots}{
ordered vector of values, which forces the method to start with these knots. 
If \code{knots} is not specified, the program starts with one knot at zero and then 
employs stepwise addition of knots and atoms. 
}
\item{maxknots}{ maximum number of knots allowed in the model. Does not need to be 
specified, since the program has a default for \code{maxdim} and 
the number of dimensions equals the number of knots plus the number of 
atoms. If \code{maxknots = 1} the fitted spectral density function is 
constant. 
}
\item{atoms}{
ordered vector of values, which forces the method to start with discrete 
components at these frequencies. The values of atoms are rounded 
to the nearest multiple of \eqn{\frac{2\pi}T}{2*pi/T}. 
If atoms is not specified, the program starts with no atoms and then performs 
stepwise addition of knots and atoms. 
}
\item{maxatoms}{
maximum number of discrete components allowed in the model. Does not need to be 
specified, since the program has a default for \code{maxdim} and 
the number of dimensions equals the number of knots plus the number of 
atoms. If \code{maxatoms = 0} a continuous 
spectral distribution is fit. 
}
\item{maxdim}{
maximum number of basis 
functions allowed in the model (default is 
\eqn{\max(15,4\times\mbox{length(period)}^{0.2})}{max(15,4*length(period)^0.2)}). 
}
\item{odd}{
see \code{period}. If \code{period} is not specified, \code{odd} is not relevant. 
}
\item{updown}{
the maximal number of times that \code{lspec} should go through a cycle of stepwise 
addition and stepwise deletion until a stable solution is reached. 
}
\item{silent}{
should printing of information be suppressed?}
}
\value{Object of class \code{lspec}.
The output is organized to serve as input for \code{\link{plot.lspec}}
(summary plots),
\code{\link{summary.lspec}} (summarizes fitting), \code{\link{clspec}} (for
autocorrelations and autocovariances), \code{\link{dlspec}} (for spectral density and line-spectrum,) 
\code{\link{plspec}} (for the spectral distribution), and \code{\link{rlspec}}
(for random time series with the same spectrum).

\item{call}{
the command that was executed. 
}
\item{thetap}{
coefficients of the polynomial part of the spline. 
}
\item{nknots}{
the number of knots that were retained. 
}
\item{knots}{
vector of the locations of the knots in the logspline model. 
Only the knots that were retained are in this vector.  
}
\item{thetak}{
coefficients of the knot part of the 
spline. The k-th coefficient is the coefficient 
of  \eqn{(x-t(k))^3_+}. 
}
\item{natoms}{
the number of atoms that were retained. 
}
\item{atoms}{
vector of the locations of the atoms in the model. 
Only the atoms that were retained are in this vector.  
}
\item{mass}{
The k-th coefficient is the mass at \code{atom[k]}. 
}
\item{logl}{
the log-likelihood of the model. 
}
\item{penalty}{
the penalty that was used. 
}
\item{minmass}{
the minimum mass for an atom that was allowed. 
}
\item{sample}{
the sample size that was used, either computed as \code{length(data)} or 
as \code{(2 * length(period))}  when \code{odd = FALSE} or as
\code{(2 * length(period) + 1)}  when \code{odd = TRUE}. 
}
\item{updown}{
the actual number of times that \code{lspec} went through a cycle of  
stepwise addition and stepwise  deletion  
until a stable solution was reached, or 
minus the number of times that lspec went through a cycle of  
stepwise addition and stepwise  deletion until it decided to quit. 
}
}
\references{
Charles Kooperberg, Charles J. Stone, and Young K. Truong (1995).
Logspline Estimation of a Possibly Mixed Spectral Distribution.
\emph{Journal of Time Series Analysis}, \bold{16}, 359-388.

Charles J. Stone, Mark Hansen, Charles Kooperberg, and Young K. Truong.
The use of polynomial splines and their tensor products in extended
linear modeling (with discussion) (1997).  \emph{Annals of Statistics},
\bold{25}, 1371--1470.}
\author{Charles Kooperberg \email{clk@fhcrc.org}.}
\seealso{\code{\link{plot.lspec}}, \code{\link{summary.lspec}}, \code{\link{clspec}}, \code{\link{dlspec}},
\code{\link{plspec}}, \code{\link{rlspec}}.}
\examples{
data(co2)
co2.detrend <- unstrip(lm(co2~c(1:length(co2)))$residuals)
fit <- lspec(co2.detrend)
}
\keyword{ts}
\keyword{smooth}

\eof
\name{oldlogspline}
\alias{oldlogspline}
\title{ Logspline Density Estimation - 1992 version }
\description{Fits a \code{logspline} density using splines to approximate the log-density
using 
the 1992 knot deletion algorithm (\code{\link{oldlogspline}}). 
The 1997 algorithm using knot
deletion and addition is available using the \code{\link{logspline}} function.
}
\usage{oldlogspline(uncensored, right, left, interval, lbound,
ubound, nknots, knots, penalty, delete = TRUE) }
\arguments{
\item{uncensored}{
vector of uncensored observations from the distribution whose density is 
to be estimated. If there are no uncensored observations, this argument can 
be omitted. However, either \code{uncensored} or \code{interval} must be specified. 
}
\item{right}{
vector of right censored observations from the distribution 
whose density is to be estimated. If there are no right censored 
observations, this argument can be omitted. 
}
\item{left}{
vector of left censored observations from the distribution 
whose density is to be estimated. If there are no left censored 
observations, this argument can be omitted. 
}
\item{interval}{
two column matrix of lower and upper bounds of observations 
that are interval censored from the distribution whose density is 
to be estimated. If there are no interval censored observations, this 
argument can be omitted. 
}
\item{lbound,ubound}{
lower/upper bound for the support of the density. For example, if there 
is a priori knowledge that the density equals zero to the left of 0, 
and has a discontinuity at 0, 
the user could specify \code{lbound = 0}. However, if the density is  
essentially zero near 0, one does not need to specify \code{lbound}. The
default for \code{lbound} is \code{-inf} and the default for
 \code{ubound} is \code{inf}.
}
\item{nknots}{
forces the method to start with nknots knots (\code{delete = TRUE}) or to fit a 
density with nknots knots (\code{delete = FALSE}). The method has an automatic rule 
for selecting nknots if this parameter is not specified. 
}
\item{knots}{
ordered vector of values (that should cover the complete range of the 
observations), which forces the method to start with these knots (\code{delete = TRUE})
or to fit a density with these knots \code{delete = FALSE}). Overrules \code{nknots}. 
If \code{knots} is not specified, a default knot-placement rule is employed. 
}
\item{penalty}{
the parameter to be used in the AIC criterion. The method chooses 
the number of knots that minimizes \code{-2 * loglikelihood + penalty * (number of knots - 1)}. 
The default is to use  a penalty parameter of \code{penalty = log(samplesize)} as in BIC. The effect of 
this parameter is summarized in \code{\link{summary.oldlogspline}}. 
}
\item{delete}{
should stepwise knot deletion be employed? 
}
}
\value{Object of the class \code{oldlogspline}, that is intended as input for
\code{\link{plot.oldlogspline}}, 
\code{\link{summary.oldlogspline}}, 
\code{\link{doldlogspline}} (densities), 
\code{\link{poldlogspline}} (probabilities),\cr
\code{\link{qoldlogspline}} (quantiles),
\code{\link{roldlogspline}} (random numbers from the fitted distribution).

The object has the following members: 

\item{call}{
the command that was executed. 
}
\item{knots }{
vector of the locations of the knots in the \code{oldlogspline} model. 
old
}
\item{coef}{
coefficients of the spline. The first coefficient is the constant term, 
the second is the linear term and the k-th \eqn{(k>2)} is the coefficient 
of \eqn{(x-t(k-2))^3_+} (where \eqn{x^3_+} means the positive part of the third power
of \eqn{x}, 
and \eqn{t(k-2)} means knot \eqn{k-2}). If a coefficient is zero the corresponding 
knot was deleted from the model. 
}
\item{bound}{
first element: 0 - \code{lbound} was \eqn{-\inf}{-infinity,} 1 it was something else; second 
element: \code{lbound}, if specified; third element: 0 - \code{ubound} was \eqn{\inf}{infinity}, 
1 it was something else; fourth element: \code{ubound}, if specified. 
}
\item{logl}{
the \code{k}-th element is the log-likelihood of the fit with \code{k+2} knots. 
}
\item{penalty}{
the penalty that was used. 
}
\item{sample}{
the sample size that was used. 
}
\item{delete}{
was stepwise knot deletion employed? 
}
}
\references{Charles Kooperberg and Charles J. Stone.  Logspline density estimation
for censored data (1992). \emph{Journal of Computational and Graphical
Statistics}, \bold{1}, 301--328.

Charles J. Stone, Mark Hansen, Charles Kooperberg, and Young K. Truong.
The use of polynomial splines and their tensor products in extended
linear modeling (with discussion) (1997).  \emph{Annals of Statistics},
\bold{25}, 1371--1470.}
\author{ Charles Kooperberg \email{clk@fhcrc.org}.}
\seealso{ 
\code{\link{logspline}},      
\code{\link{oldlogspline}},
\code{\link{plot.oldlogspline}},
\code{\link{summary.oldlogspline}},\cr
\code{\link{doldlogspline}},
\code{\link{poldlogspline}},
\code{\link{qoldlogspline}},
\code{\link{roldlogspline}}.}
\examples{
# A simple example
y <- rnorm(100)
fit <- oldlogspline(y)       
plot(fit)
# An example involving censoring and a lower bound
y <- rlnorm(1000)
censoring <- rexp(1000) * 4
delta <- 1 * (y <= censoring)
y[delta == 0] <- censoring[delta == 0]
fit <- oldlogspline(y[delta == 1], y[delta == 0], lbound = 0)
}
\keyword{distribution}
\keyword{smooth}

\eof
\name{persp.polymars}
\alias{persp.polymars}
\title{Polymars: multivariate adaptive polynomial spline regression}
\description{This function is not intended for direct use. It is called
by \code{\link{plot.polymars}}.}
\usage{persp.polymars(x, predictor1, predictor2, response, n = 33,
xlim, ylim, xx, contour.polymars, main, intercept, ...) }
\arguments{
\item{x, predictor1, predictor2} {this function is not intended to be called directly.}
\item{response, n, xlim, ylim} {this function is not intended to be called directly.}
\item{xx, contour.polymars} {this function is not intended to be called directly.}
\item{main, intercept, ...} {this function is not intended to be called directly.}
}
\details{
This function produces a 3-d contour or perspective plot. It is intended
to be called by \code{\link{plot.polymars}}.}
\references{Charles Kooperberg, Smarajit Bose, and  Charles J. Stone (1997).
Polychotomous regression. \emph{Journal of the American Statistical
Association}, \bold{92}, 117--127.

Charles J. Stone, Mark Hansen, Charles Kooperberg, and Young K. Truong.
The use of polynomial splines and their tensor products in extended
linear modeling (with discussion) (1997).  \emph{Annals of Statistics},
\bold{25}, 1371--1470.}
\author{Martin O'Connor.}
\seealso{\code{\link{polymars}}, 
\code{\link{plot.polymars}}.}
\keyword{smooth}
\keyword{nonlinear}

\eof
\name{plot.hare}
\alias{plot.hare}
\title{Hare: hazard regression}
\description{Plots a density, distribution function, hazard 
function or survival function for
a \code{hare} object.}
}
\usage{plot.hare(x, cov, n = 100, which = 0, what = "d", time, add = FALSE, xlim,
xlab, ylab, type, ...) }
\arguments{
\item{x}{\code{hare} object, typically the result of \code{\link{hare}}.  }
\item{cov}{a vector of length \code{fit\$ncov}, indicating for which combination of  
covariates the plot should be made. Can be omitted only if \code{fit\$ncov} is 0.  }
\item{n}{the number of equally spaced points at which to plot the function.  }
\item{which}{for which coordinate should the plot be made. 0: time; positive value 
i: covariate i. Note that if which is the positive value i, then the 
element corresponding to this covariate must be given in \code{cov} even 
though its actual value is irrelevant.  }
\item{what}{
what should be plotted: \code{"d"} (density), \code{"p"} (distribution function), \code{"s"} (survival 
function) or \code{"h"} (hazard function).  }
\item{time}{if which is not equal to 0, the value of time for which the plot should be made.  }
\item{add}{should the plot be added to an existing plot?  }
\item{xlim}{plotting limits; default is from the maximum of 0 
and 10\% before the 1st percentile
to  the minimmum of
10\% further than the 99th percentile and the largest observation.}
\item{xlab,ylab}{labels for the axes. Per default no labels are printed.}
\item{type}{plotting type. The default is lines.}
\item{...}{all other plotting options are passed on.  }
}
\details{This function produces a plot of a \code{\link{hare}} fit at \code{n} equally 
spaced points roughly covering the support of the density. (Use 
\code{xlim=c(from,to)} to change the range of these points.) 
}
\references{Charles Kooperberg, Charles J. Stone and Young K. Truong (1995).
Hazard regression.  \emph{Journal of the American Statistical
Association}, \bold{90}, 78-94.

Charles J. Stone, Mark Hansen, Charles Kooperberg, and Young K. Truong.
The use of polynomial splines and their tensor products in extended
linear modeling (with discussion) (1997).  \emph{Annals of Statistics},
\bold{25}, 1371--1470.}
\author{Charles Kooperberg \email{clk@fhcrc.org}.}
\seealso{\code{\link{hare}},
\code{\link{summary.hare}},
\code{\link{dhare}},
\code{\link{hhare}},
\code{\link{phare}},
\code{\link{qhare}},
\code{\link{rhare}}.}
\examples{
fit <- hare(testhare[,1], testhare[,2], testhare[,3:8])       
# hazard curve for covariates like case 1 
plot(fit, testhare[1,3:8], what = "h") 
# survival function as a function of covariate 2, for covariates as case 1 at t=3 
plot(fit, testhare[1,3:8], which = 2, what = "s",  time = 3)  
}
\keyword{distribution}
\keyword{smooth}
\keyword{survival}

\eof
\name{plot.heft}
\alias{plot.heft}
\title{Heft: hazard estimation with flexible tails}
\description{Plots a density, distribution function, hazard
function or survival function for
a \code{heft} object.}
\usage{plot.heft(x, n = 100, what = "d", add = FALSE, xlim, xlab, ylab,
type, ...) }
\arguments{
\item{x}{\code{heft} object, typically the result of \code{\link{heft}}.  }
\item{n}{the number of equally spaced points at which to plot the function.  }
\item{what}{
what should be plotted: \code{"d"} (density), \code{"p"} (distribution function), \code{"s"} (survival
function) or \code{"h"} (hazard function).  }
\item{add}{should the plot be added to an existing plot?  }
\item{xlim}{plotting limits; default is from the maximum of 0
and 10\% before the 1st percentile
to  the minimmum of
10\% further than the 99th percentile and the largest observation.}
\item{xlab,ylab}{labels for the axes. The default is no labels.}
\item{type}{plotting type. The default is lines.}
\item{...}{all other plotting options are passed on.  }
}
\details{This function produces a plot of a \code{\link{heft}} fit at \code{n} equally
spaced points roughly covering the support of the density. (Use
\code{xlim=c(from,to)} to change the range of these points.)
}
\references{Charles Kooperberg, Charles J. Stone and Young K. Truong (1995).
Hazard regression.  \emph{Journal of the American Statistical
Association}, \bold{90}, 78-94.

Charles J. Stone, Mark Hansen, Charles Kooperberg, and Young K. Truong.
The use of polynomial splines and their tensor products in extended
linear modeling (with discussion) (1997).  \emph{Annals of Statistics},
\bold{25}, 1371--1470.}
\author{Charles Kooperberg \email{clk@fhcrc.org}.}
\seealso{
\code{\link{heft}},
\code{\link{summary.heft}},
\code{\link{dheft}},
\code{\link{hheft}},
\code{\link{pheft}},
\code{\link{qheft}},
\code{\link{rheft}}.}
\examples{
fit1 <- heft(testhare[,1], testhare[,2])
plot(fit1, what = "h")
# modify tail behavior
fit2 <- heft(testhare[,1], testhare[,2], leftlog = FALSE, rightlog = FALSE, 
    leftlin = TRUE)   
plot(fit2, what = "h", add = TRUE,lty = 2)
fit3 <- heft(testhare[,1], testhare[,2], penalty = 0)   # select largest model
plot(fit3, what = "h", add = TRUE,lty = 3)
}
\keyword{distribution}
\keyword{smooth}
\keyword{survival}

\eof
\name{plot.logspline}
\alias{plot.logspline}
\title{Logspline Density Estimation }
\description{Plots a \code{logspline} density, distribution function, hazard 
function or survival function 
from 
a logspline density that was fitted using
the 1997 knot addition and deletion algorithm (\code{\link{logspline}}). 
The 1992 algorithm is available using the \code{\link{oldlogspline}} function.
}
\usage{plot.logspline(x, n = 100, what = "d", add = FALSE, xlim, xlab = "",
ylab = "", type = "l", ...) 
}
\arguments{
\item{x}{\code{logspline} object, typically the result of \code{\link{logspline}}.}
\item{n}{the number of equally spaced points at which to plot the density.  }
\item{what}{what should be plotted: 
\code{"d"} (density), \code{"p"} (distribution function), \code{"s"} (survival 
function) or \code{"h"} (hazard function).  }
\item{add}{should the plot be added to an existing plot.}
\item{xlim}{
range of data on which to plot. Default is from the 1th to the 99th percentile of
the density, extended by 10\% on each end.}
\item{xlab,ylab}{labels plotted on the axes.  }
\item{type}{type of plot.}
\item{...}{other plotting options, as desired}
}
\details{This function produces a plot of a \code{\link{logspline}} fit at \code{n} equally 
spaced points roughly covering the support of the density. (Use 
\code{xlim = c(from, to)} to change the range of these points.) 
}
\references{Charles Kooperberg and Charles J. Stone.  Logspline density estimation
for censored data (1992). \emph{Journal of Computational and Graphical
Statistics}, \bold{1}, 301--328.

Charles J. Stone, Mark Hansen, Charles Kooperberg, and Young K. Truong.
The use of polynomial splines and their tensor products in extended
linear modeling (with discussion) (1997).  \emph{Annals of Statistics},
\bold{25}, 1371--1470.}
\author{Charles Kooperberg \email{clk@fhcrc.org}.}
\seealso{
\code{\link{logspline}},      
\code{\link{summary.logspline}},
\code{\link{dlogspline}},
\code{\link{plogspline}},
\code{\link{qlogspline}},
\code{\link{rlogspline}},

\code{\link{oldlogspline}}.}
\examples{
y <- rnorm(100)
fit <- logspline(y)       
plot(fit) 
}
\keyword{distribution}
\keyword{smooth}

\eof
\name{plot.lspec}
\alias{plot.lspec}
\title{Lspec: logspline estimation of a spectral distribution}
\description{Plots a spectral density function,
line spectrum, or spectral distribution from a model fitted with \code{\link{lspec}} }
\usage{plot.lspec(x, what = "b", n, add = FALSE, xlim, ylim, xlab = "", ylab = "",
type, ...) }
\arguments{
\item{x}{\code{lspec} object, typically the result of \code{\link{lspec}}.}
\item{what}{what should be plotted: b (spectral density and line spectrum 
superimposed), d (spectral density function), 
l (line spectrum)  or p  (spectral distribution function).  }
\item{n}{the number of equally spaced points at which to plot the fit;  default is \code{max(100,fit\$sample)}.  }
\item{add}{indicate that the plot should be added to an existing plot.  }
\item{xlim}{X-axis plotting limits: default is \eqn{c(0,\pi)}{c(0,pi)}, except
when what = "p", when the default is \eqn{c(-\pi,\pi)}{c(-pi,pi)}.}
\item{ylim}{Y-axis plotting limits.}
\item{xlab,ylab}{axis labels.}
\item{type}{plotting type; default is \code{"l"} when \code{what = "d"}
 and \code{what = "p"}, \code{"h"} when \code{what = "l"}, and
a combination of \code{"h"} and \code{"l"} when \code{what ="b"}}
\item{...}{all regular plotting options are passed on.  }
}
\note{If \code{what = "p"} 
the plotting range cannot extend beyond the interval \eqn{[-\pi,\pi]}{[-pi,pi]}.  }
\references{
Charles Kooperberg, Charles J. Stone, and Young K. Truong (1995).
Logspline Estimation of a Possibly Mixed Spectral Distribution.
\emph{Journal of Time Series Analysis}, \bold{16}, 359-388.

Charles J. Stone, Mark Hansen, Charles Kooperberg, and Young K. Truong.
The use of polynomial splines and their tensor products in extended
linear modeling (with discussion) (1997).  \emph{Annals of Statistics},
\bold{25}, 1371--1470.}
\author{Charles Kooperberg \email{clk@fhcrc.org}.}
\seealso{\code{\link{lspec}}, \code{\link{summary.lspec}}, \code{\link{clspec}}, \code{\link{dlspec}},
\code{\link{plspec}}, \code{\link{rlspec}}.}
\examples{
data(co2)
co2.detrend <- lm(co2~c(1:length(co2)))$residuals
fit <- lspec(co2.detrend)
plot(fit)
}
\keyword{ts}
\keyword{smooth}

\eof
\name{plot.oldlogspline}
\alias{plot.oldlogspline}
\title{Logspline Density Estimation - 1992 version }
\description{Plots an \code{oldlogspline} density, distribution function, hazard 
function or survival function 
from 
a logspline density that was fitted using
the 1992 knot deletion algorithm.
The 1997 algorithm using knot
deletion and addition is available using the \code{\link{logspline}} function.
}
\usage{plot.oldlogspline(x, n = 100, what = "d", xlim, xlab = "", ylab = "",
type = "l", ...) }
\arguments{
\item{x}{\code{logspline} object, typically the result of \code{\link{logspline}}.}
\item{n}{the number of equally spaced points at which to plot the density.  }
\item{what}{what should be plotted: 
\code{"d"} (density), \code{"p"} (distribution function), \code{"s"} (survival 
function) or \code{"h"} (hazard function).  }
\item{xlim}{
range of data on which to plot. Default is from the 1th to the 99th percentile of
the density, extended by 10\% on each end.}
\item{xlab,ylab}{labels plotted on the axes.  }
\item{type}{type of plot.}
\item{...}{other plotting options, as desired}
}
\details{This function produces a plot of a \code{\link{oldlogspline}} fit at \code{n} equally
spaced points roughly covering the support of the density. (Use
\code{xlim=c(from,to)} to change the range of these points.)
}
\references{Charles Kooperberg and Charles J. Stone.  Logspline density estimation
for censored data (1992). \emph{Journal of Computational and Graphical
Statistics}, \bold{1}, 301--328.

Charles J. Stone, Mark Hansen, Charles Kooperberg, and Young K. Truong.
The use of polynomial splines and their tensor products in extended
linear modeling (with discussion) (1997).  \emph{Annals of Statistics},
\bold{25}, 1371--1470.}
\author{Charles Kooperberg \email{clk@fhcrc.org}.}
\seealso{
\code{\link{logspline}},
\code{\link{oldlogspline}},
\code{\link{summary.oldlogspline}},
\code{\link{doldlogspline}},
\code{\link{poldlogspline}},\cr
\code{\link{qoldlogspline}},
\code{\link{roldlogspline}}.}
\examples{
y <- rnorm(100)
fit <- oldlogspline(y)       
plot(fit) 
}
\keyword{distribution}
\keyword{smooth}

\eof
\name{plot.polyclass}
\alias{plot.polyclass}
\title{Polyclass: polychotomous regression and multiple classification}
\description{Probability or classification plots for a  \code{\link{polyclass}} model.  }
\usage{plot.polyclass(x, cov, which, lims, what, data, n, xlab="", ylab="",
zlab="", ...) }
\arguments{
\item{x}{\code{polyclass} object, typically the result of \code{\link{polyclass}}. }
\item{cov}{
a vector of length \code{fit\$ncov}, indicating for which combination of  
covariates the plot should be made. Can never be omitted. Should always have 
length \code{fit\$ncov}, even if some values are irrelevant.  }
\item{which}{
for which covariates should the plot be made.  
Number or a character string defining the name, if the 
same names were used with the call to \code{\link{polyclass}}. Which should have length one if 
\code{what} is 6 or larger and length two if \code{what} is 5 or smaller.  }
\item{lims}{plotting limits. If omitted, the plot is made over the same range 
of the covariate as in the original data. Otherwise a vector of 
length two of the form \code{c(min, max)} if what is 6 or larger and a vector of 
length four of the form \code{c(xmin, xmax, ymin ,ymax)} if \code{what} is 5 or smaller.  }
\item{what}{
an integer between 1 and 8, defining the type of plot to be made. 
\enumerate{
\item Plots the probability of one class as a contour plot of two variables. 
\item Plots the probability of one class as a perspective plot of two variables. 
\item Plots the probability of one class as an image plot of two variables. 
\item Classifies the area as a contour plot of two variables. 
\item Classifies the area as an image plot of two variables. 
\item Classifies the line as a plot of one variable. 
\item Plots the probabilities of all classes as a function of one variable. 
\item Plots the probability of one class as a function of one variable. 
}
}
\item{data}{Class for which the plot is made. Should be provided if \code{what} is 1, 2, 3 or 8.  }
\item{n}{
the number of equally spaced points at which to plot the fit. The 
default is 250 if \code{what} is 6 or larger or 50 (which results in 2500 plotting 
points) if \code{what} is 5 or smaller. 
}
\item{xlab,ylab,zlab}{axis plotting labels.}
\item{...}{
all other options are passed on.  }
}
\references{Charles Kooperberg, Smarajit Bose, and  Charles J. Stone (1997).
Polychotomous regression. \emph{Journal of the American Statistical
Association}, \bold{92}, 117--127.

Charles J. Stone, Mark Hansen, Charles Kooperberg, and Young K. Truong.
The use of polynomial splines and their tensor products in extended
linear modeling (with discussion) (1997).  \emph{Annals of Statistics},
\bold{25}, 1371--1470.}
\author{Charles Kooperberg \email{clk@fhcrc.org}.}
\seealso{
\code{\link{polyclass}},
\code{\link{summary.polyclass}},
\code{\link{beta.polyclass}},
\code{\link{cpolyclass}},
\code{\link{ppolyclass}},
\code{\link{rpolyclass}}.}
\examples{
data(iris)
fit.iris <- polyclass(iris[,5], iris[,1:4])
plot(fit.iris, iris[64,1:4], which=c(3,4), data=2, what=1) 
plot(fit.iris,iris[64,1:4], which=c(3,4), what=5) 
plot(fit.iris,iris[64,1:4], which=4, what=7) 
}
\keyword{smooth}
\keyword{nonlinear}

\eof
\name{plot.polymars}
\alias{plot.polymars}
\title{Polymars: multivariate adaptive polynomial spline regression}
\description{Produces two and three dimensional plots of the 
fitted values from a \code{polymars} object. 
}
\usage{plot.polymars(x, predictor1, response, predictor2, xx, add = FALSE, n,
xyz = FALSE, contour.polymars = FALSE, xlim, ylim, intercept, ...) }
\arguments{
\item{x}{\code{polymars} object, typically the result of \code{\link{polymars}}. }
\item{predictor1}{the index of a predictor that was used when the \code{polymars} model was fit. 
For the two dimensional plots, this variable is plotted along the X-axis.  }
\item{response}{
if the model was fitted to multiple response data the response index 
should be specified. }
\item{predictor2}{
the index of a predictor that was used when the \code{polymars} model was fit. For the three  
dimensional plots, this variable is plotted along the Y-axis.   
See \code{xyz}. 
}
\item{xx}{
should be a vector of length equal to the number of predictors in the  
original data set. The values should be in the same order as in the original  
dataset. By default the function uses the median values of the data that was  
used to fit the model.  Although the values for predictor and predictor2 are  
not used, they should still be provided as part of \code{xx}. 
}
\item{add}{
should the plot be added to a previously created plot? Works only for two 
dimensional plots. 
}
\item{n}{
number of plotting points (2 dimensional plot) or plotting points along each 
axis (3 dimensional plot). The default is \code{n = 100} for 2 dimensional plots and 
\code{n = 33} for 3 dimensional plots. 
}
\item{xyz}{
is the plot being made a 3 dimensional plot? 
If there is only one response it need not be set, if two numerical values  
accompany the model in the call they will be understood as two predictors 
for a 3-d plot. By default a 3-d plot uses the \code{\link{persp}} function. 
Categorical predictors cannot be used for 3 dimensional plots. 
}
\item{contour.polymars}{
if the plot being made a 3 dimensional plot should it be made as a contour plot 
(\code{TRUE}) or a perspective plot (\code{FALSE}).
function \link{contour} is being made. 
}
\item{intercept}{
 Setting intercept equal to \code{FALSE} evaluates the object without intercept. The  
intercept may also be given any numerical value which overrides the fitted  
coefficient from the object. The default is \code{TRUE}.
}
\item{xlim,ylim}{Plotting limits. The function tries to choose intelligent limits itself}
\item{...}{
other options are passed on.
}
}
\details{
This function produces a 2-d plot of 1 predictor and response of a \code{polymars} object
at n equally spaced points or a 3-d plot of two predictors and response of a 
\code{polymars} object.  The range of the plot is by default equal to the range of the 
particular predictor(s) in the original data, but this can be changed by  
\code{xlim = c(from, to)} and
\code{ylim = c(from, to)}.
}
\references{Charles Kooperberg, Smarajit Bose, and  Charles J. Stone (1997).
Polychotomous regression. \emph{Journal of the American Statistical
Association}, \bold{92}, 117--127.

Charles J. Stone, Mark Hansen, Charles Kooperberg, and Young K. Truong.
The use of polynomial splines and their tensor products in extended
linear modeling (with discussion) (1997).  \emph{Annals of Statistics},
\bold{25}, 1371--1470.}
\author{Martin O'Connor.}
\seealso{
\code{\link{polymars}},
\code{\link{predict.polymars}},
\code{\link{summary.polymars}}.}
\examples{
data(state)
state.pm <- polymars(state.region, state.x77, knots = 15, classify = TRUE, gcv = 1)
plot(state.pm, 3, 4)
}
\keyword{smooth}
\keyword{nonlinear}

\eof
\name{polyclass}
\alias{polyclass}
\title{Polyclass: polychotomous regression and multiple classification}
\description{Fit a polychotomous regression and multiple classification 
using linear splines and selected tensor products.  }
\usage{polyclass(data, cov, weight, penalty, maxdim, exclude, include,
additive = FALSE, linear, delete = 2, fit,  silent = TRUE, 
normweight = TRUE, tdata, tcov, tweight, cv, select, loss, seed) }
\arguments{
\item{data}{vector of classes:
\code{data} should ranges over consecutive integers with 0 or 1 as the minimum value. 
}
\item{cov}{covariates: matrix with as many rows as the length of \code{data}.  }
\item{weight}{optional vector of case-weights.  Should have the same length as 
\code{data}.}
\item{penalty}{
the parameter to be used in the AIC criterion if the 
model selection is carried out by AIC.  The program chooses 
the number of knots that minimizes \code{-2 * loglikelihood + penalty * (dimension)}. 
The default is to use \code{penalty = log(length(data))} as in BIC. If the model 
selection is carried out by cross-validation or using a test set, the 
program uses the number of knots that minimizes 
\code{loss + penalty * dimension * (loss for smallest model)}. In this case 
the default of \code{penalty} is 0. 
}
\item{maxdim}{
maximum dimension (default is 
\eqn{\min(n, 4 * n^{1/3}*(cl-1)}{\code{min(n, 4 * n^(1/3) * (cl - 1)}}, where 
\eqn{n} is \code{length(data)} and
\eqn{cl} the number of classes.
}
\item{exclude}{
combinations to be excluded - this should be a matrix with 2 
columns - if for example \code{exclude[1, 1] = 2} and \code{exclude[1, 2] = 3} no 
interaction between covariate 2 and 3 is included. 0 represents time. 
}
\item{include}{
those combinations that can be included. Should have the same format 
as \code{exclude}. Only one of \code{exclude} and \code{include} can be specified .
}
\item{additive}{should the model selection be restricted to additive models?  }
\item{linear}{
vector indicating for which of the variables no knots should 
be entered. For example, if \code{linear = c(2, 3)} no knots for either covariate 
2 or 3 are entered. 0 represents time. 
}
\item{delete}{
should complete basis functions be deleted at once (2), should 
only individual dimensions be deleted (1) or should only the addition 
stage of the model selection be carried out (0)? 
}
\item{fit}{
\code{polyclass} object. If  \code{fit} is specified, \code{\link{polyclass}} adds 
basis functions starting with those in \code{fit}. 
}
\item{silent}{
suppresses the printing of diagnostic output about basis functions added 
or deleted, Rao-statistics, Wald-statistics and log-likelihoods. 
}
\item{normweight}{
should the weights be normalized so that they average to one? This option 
has only an effect if the model is selected using AIC. 
}
\item{tdata,tcov,tweight}{
test set. Should satisfy the same requirements as \code{data}, \code{cov} and
\code{weight}. If 
all test set weights are one, \code{tweight} can be omitted. If \code{tdata} and \code{tcov} are 
specified, the model selection is carried out using this test set, irrespective 
of the input for \code{penalty} or \code{cv}. 
}
\item{cv}{
in how many subsets should the data be divided for cross-validation? If \code{cv} is 
specified and tdata is omitted, the model selection is carried out by 
cross-validation.
}
\item{select}{
if a test set is provided, or if the model is selected using cross validation, 
should the model be select that minimizes (misclassification) loss (0), that 
maximizes test set log-likelihood (1) or that minimizes test set 
squared error loss (2)? 
}
\item{loss}{
a rectangular matrix specifying the loss function, whose 
size is the number of 
classes times number of actions. 
Used for cross-validation and test set model 
selection. \code{loss[i, j]} contains the loss for 
assigning action \code{j}  to an object whose true class is \code{i}. 
The default is 1 minus the identity matrix. 
\code{loss} does not need to be square.
}
\item{seed}{
optional 
seed for the random number generator that determines the sequence of the 
cases for cross-validation. If the seed has length 12 or more, 
the first twelve elements are assumed to be \code{.Random.seed}, otherwise 
the function \code{\link{set.seed}} is used.  
If \code{seed} is 0 or \code{rep(0, 12)}, it is assumed that the user 
has already provided a (random) ordering. 
If \code{seed} is not provided, while a fit with 
an element \code{fit\$seed} is provided, 
\code{.Random.seed} is set using \code{set.seed(fit\$seed)}. Otherwise 
the present value of \code{.Random.seed} is used. 
}
}
\value{
The output is an object of class \code{polyclass}, organized
to serve as input for \code{\link{plot.polyclass}}, 
\code{\link{beta.polyclass}},
\code{\link{summary.polyclass}}, \code{\link{ppolyclass}} (fitted probabilities),
\code{\link{cpolyclass}} (fitted classes) and \code{\link{rpolyclass}} (random classes). 
The function returns a list with the following members: 

\item{call}{the command that was executed.  }
\item{ncov}{number of covariates.  }
\item{ndim}{number of dimensions of the fitted model.  }
\item{nclass}{number of classes.  }
\item{nbas}{number of basis functions.  }
\item{naction}{number of possible actions that are considered.  }
\item{fcts}{matrix of size \code{nbas x (nclass + 4)}. each row is a basis function. 
First element: first covariate involved (\code{NA} = constant); 

second element: which knot (\code{NA} means: constant or linear); 

third element: second covariate involved (\code{NA} means: this is a function 
of one variable); 

fourth element: knot involved (if the third element is \code{NA}, of no relevance); 

fifth, sixth,...  element: beta (coefficient) for class one, two, ... 
}
\item{knots}{
a matrix with \code{ncov} rows.
Covariate \code{i} has row \code{i+1}, time has row 1. 
First column: number of knots in this dimension;
other columns: the knots, appended with \code{NA}s to make it a matrix.
}
\item{cv}{
in how many sets was the data divided for cross-validation. 
Only provided if \code{method = 2}. 
}
\item{loss}{
the loss matrix used in cross-validation and test set. 
Only provided if \code{method = 1} or \code{method = 2}.
}
\item{penalty}{
the parameter used in the AIC criterion. Only provided if \code{method = 0}.
}
\item{method}{
0 = AIC, 1 = test set, 2 = cross-validation. 
}
\item{ranges}{
column \code{i} gives the range of the \code{i}-th covariate. 
}
\item{logl}{
matrix with eight or eleven columns. Summarizes fits. 
Column one indicates the dimension, column 
column two the AIC or loss value, whichever was 
used during the model selection 
appropriate, column three four and five give the training set log-likelihood, 
(misclassification) loss and squared error loss, columns six to 
eight give the same information for the test set, column nine (or column 
six if \code{method = 0} or \code{method = 2}) indicates whether the 
model was fitted during the addition stage (1) or during the deletion stage (0), 
column ten and eleven (or seven and eight) the minimum and maximum 
penalty parameter for which AIC would have selected this model. 
}
\item{sample}{sample size. 
}
\item{tsample}{the sample size of the test set. Only prvided if \code{method = 1}.  }
\item{wgtsum}{sum of the case weights.  }
\item{covnames}{names of the covariates.  }
\item{classnames}{(numerical) names of the classes.  }
\item{cv.aic}{the penalty value that was determined optimal by 
by cross validation. Only provided if \code{method = 2}.  }
\item{cv.tab}{table with three columns. Column one and two indicate the penalty parameter 
range for which the cv-loss in column three would be realized.  
Only provided if \code{method = 2}.}
\item{seed}{the random seed that was used to determine the order 
of the cases for cross-validation. 
Only provided if \code{method = 2}.}
\item{delete}{
were complete basis functions deleted at once (2), were 
only individual dimensions deleted (1) or was only the addition 
stage of the model selection carried out (0)? 
}
\item{beta}{
moments of basisfunctions. Needed for \code{\link{beta.polyclass}}.
}
\item{select}{
if a test set is provided, or if the model is selected using cross validation, 
was the model selected that minimized (misclassification) loss (0), that 
maximized test set log-likelihood (1) or that minimized test set 
squared error loss (2)? 
}
\item{anova}{
matrix with three columns. The first two elements in a line 
indicate the subspace to which the line refers. The third element indicates 
the percentage of variance explained by that subspace. 
}
\item{twgtsum}{
sum of the test set case weights (only if \code{method = 1}). 
}
}
\references{Charles Kooperberg, Smarajit Bose, and  Charles J. Stone (1997).
Polychotomous regression. \emph{Journal of the American Statistical
Association}, \bold{92}, 117--127.

Charles J. Stone, Mark Hansen, Charles Kooperberg, and Young K. Truong.
The use of polynomial splines and their tensor products in extended
linear modeling (with discussion) (1997).  \emph{Annals of Statistics},
\bold{25}, 1371--1470.}
\author{Charles Kooperberg \email{clk@fhcrc.org}.}
\seealso{
\code{\link{polymars}},
\code{\link{plot.polyclass}},
\code{\link{summary.polyclass}},
\code{\link{beta.polyclass}},
\code{\link{cpolyclass}},\cr
\code{\link{ppolyclass}},
\code{\link{rpolyclass}}.}
\examples{
data(iris)
fit.iris <- polyclass(iris[,5], iris[,1:4])
}
\keyword{smooth}
\keyword{nonlinear}

\eof
\name{polymars}
\alias{polymars}
\title{Polymars: multivariate adaptive polynomial spline regression}
\description{
An adaptive regression procedure using piecewise linear splines to model the response.
}
\usage{polymars(responses, predictors, maxsize, gcv = 4, additive = FALSE, 
startmodel, weights, no.interact, knots, knot.space = 3, ts.resp, 
ts.pred, ts.weights, classify, factors, tolerance, verbose = FALSE)
}
\arguments{
\item{responses}{vector of responses, or a matrix for multiple response regression. 
In the case of a matrix each column corresponds to a response and each 
row corresponds to an observation. Missing values are not allowed. 
}
\item{predictors}{matrix of predictor variables for the regression. Each column corresponds to a 
predictor and each row corresponds to an observation in the same order as 
they appear in the response argument. Missing values are not allowed. 
}
\item{maxsize}{the maximum number of basis functions that the model is allowed to grow to in 
the stepwise addition procedure. Default is 
\eqn{\min(6*(n^{1/3}),n/4,100)}, where \code{n} is the number of observations. 
}
\item{gcv}{parameter used to find the overall best model from a sequence of fitted models. 
The residual sum of squares of a model is penalized by dividing by the square of   
\code{1-(gcv x model size)/cases}.   
A larger gcv value would tend to produce a smaller model.
}
\item{additive}{Should the fitted model be additive in the predictors? 
}
\item{startmodel}{the first model that is to be fit by \code{polymars}. It is either an 
object of the class \code{polymars} or a model dreamed up by the user.
 In that case, 
it takes the form of a \code{4 x n} matrix, where 
\code{n} is the  number of basis functions in the starting model excluding
the intercept. Each row corresponds to one basis 
function (with two possible components). Column 1 is the index of the first 
predictor involved. Column 2 is a possible knot in this predictor. If column 
2 is \code{NA}, the first component is linear. Column 3 is the possible second 
predictor involved (if column 3 is \code{NA} the basis function only depends on one 
predictor). Column 4 contains the possible knot for the predictor in column 3, 
and it is \code{NA} when this component is linear.  Example: if a row reads 
\code{3 NA 2 4.7}, the corresponding basis function is \eqn{[X_3 * (X_2-4.7)_+]}; if a row 
reads \code{2 4.3 NA NA} the corresponding basis function is \eqn{[(X_2-4.3)_+]}. 
A fifth column can be added with 1s and 0s, The 1s specify which basis 
functions of the startmodel must be in each model. Thus, these 
functions stay in the model during the whole stepwise fitting procedure. 
If \code{startmodel} is not specified \code{polymars} starts with a model that only contains  
the intercept. 
}
\item{weights}{optional vector of observation weights; if supplied, the algorithm fits to minimize the 
sum of the weights multiplied by the squared residuals.  The length of 
weights must be the same as the number of observations. The weights must 
be nonnegative. 
}
\item{no.interact}{an optional matrix used if certain predictor interactions are not allowed in the model. 
It is given as a matrix of size \code{2 x m}, with predictor indices as entries.  The two 
predictors of any row cannot have interaction terms with each other. 
}
\item{knots}{defines how the function is to find potential knots for the spline basis 
functions.  This can be set to the maximum number of knots you would 
like to be considered for each predictor. 
Usually, to avoid the design matrix becoming singular the actual number of 
knots produced is constrained to at most every third order statistic in any 
predictor. This constraint can be adjusted using the \code{knot.space} argument. 
It can also 
be a vector with the number of potential knots for each predictor. 
Again the actual number of knots produced is constrained to be at most every 
third order statistic any predictor.  
A third possibility is to provide a matrix where each columns corresponds 
to the ordered knots you would like to have considered for that predictor. 
This matrix should be filled out to a rectangular data structure with NAs. 
The default is \code{min(20, round(n/4))} knots per predictor. 
When specifying knots as a vector an entry of \code{-1} indicates that the predictor  
is a categorical variable and each unique entry in it's column is treated as a  
level. 
  
When specifying knots as a single number or a matrix and there are categorical  
variables these are specified separately as such using the factor argument. 
}
\item{knot.space}{
is an integer describing the minimum number of order statistics apart that 
two knots can be. Knots should not be too close to insure numerical stability. 
}
\item{ts.resp}{
testset responses for model selection. Should have the same number of columns 
as the training set response. A testset can be used for the model selection. 
Depending on the value of classify, either the model with the smallest testset 
residual sum of squares or the smallest testset classification error is 
provided.  Overrides \code{gcv}. 
}
\item{ts.pred}{
testset predictors. Should have the same number of columns 
as the training set predictors. 
}
\item{ts.weights}{
testset observation weights. A vector of length equal to the number of cases 
of the testset. All weights must be non-negative. 
}
\item{classify}{
when the response is discrete (categorical), polymars can be used for 
classification. In particular, when \code{classify = TRUE}, a discrete response 
with \code{K} levels is replaced by \code{K} indicator variables as response. Model 
selection is still being carried out using gcv, except when a testset is 
provided, in which case testset misclassification is used to select the best 
model. 
}
\item{factors}{
used to indicate that certain variables in the predictor set are categorical  
variables. Specified as a vector containing the appropriate predictor  
indices (column numbers of categorical variables in predictors matrix). Factors  
can also be set when the \code{knots} argument is given as a vector, with 
\code{-1} as  
the appropriate entries for factors. 
}
\item{tolerance}{
for each possible candidate to be added/deleted the resulting residual sums  
of squares of the model, with/without this candidate, must be calculated.  
The inversion of of the "X-transpose by X" matrix, X being the design matrix,  
is done by an updating procedure c.f. C.R. Rao - Linear Statistical Inference  
and Its Applications, 2nd. edition, page 33.   
In the inversion the size of the bottom right-hand entry of this matrix is  
critical. If it\code{s value is near zero or the value of it}s inverse is   
almost zero then the  
inversion procedure becomes somewhat inaccurate. The lower the tolerance value the  
more careful the procedure is in selecting candidates for addition to the model  
but it may exclude too conservatively. And the other hand if the tolerance is set 
too high a spurious result with a singular or otherwise sub-optimal model may  
occur. By default tolerance is set to 1.0e-5. 
}
\item{verbose}{
when set  to \code{TRUE}, the function will print out a line for each addition or deletion  
stage. For example, " + 8 : 5 3.25 2 NA" means adding interaction basis function  
of predictor 5 with knot at 3.25 and predictor 2 (linear), 
to make a model of size 8, including intercept. 
}
}
\value{
An object of the class \link{polymars}.
The returned object contains information about the fitting steps and the model 
selected. The first data frame contains a row for each step of the fitting 
procedure. In the columns are: a 1 for an addition step or a 0 for a deletion 
step, the size of the model at each step, residual sums of squares (RSS) and  
the generalized cross validation value (GCV), testset residual sums of squares 
or testset misclassification, whatever was used for the model selection. 
The second data frame, model, contains a row for each basis function of the 
model. Each row corresponds to one basis 
function (with two possible components). The pred1 column contains the indices 
of the first predictor of the basis function. Column knot1 is a possible knot  
in this predictor. If this column is NA, the first component is linear. If  
any of the basis functions of the model is categorical then there will be a  
level1 column. Column pred2 is the possible second predictor involved (if  
it is NA the basis function only depends on one  
predictor). Column knot2 contains the possible knot for the predictor pred2,  
and it is NA when this component is linear. This is a similar format  
to the startmodel argument together with an additional first row corresponding to the  
intercept but the startmodel doesn't use a separate column to specify levels of a  
categorical variable . If any predictor in pred2 is categorical then there will be a level2  
column. The column "coefs" (more than one column in the case of multiple response  
regression) contains the coefficients. 
The returned object also contains the fitted values and residuals of the data used 
in fitting the model. 
}
\note{The algorithm employed by \code{polymars} is different from the MARS(tm)
algorithm of Friedman (1991), though it has many similarities. (The name
\code{polymars} has been used for this algorithm well before MARS was trademarked.)
Some of the main differences are:

\code{polymars} requires linear terms of a predictor to be in the model
before nonlinear terms using the same predictor can be added;

\code{polymars} requires a univariate basis function to be in the model
before a tensor-product basis function involving the univariate
basis function can be in the model;

during stepwise deletion the same hierarchy is maintained;

\code{polymars} can be fit to multiple outcomes simultaneously, with
categorical outcomes it can be used for multiple classification; and

\code{\link{polyclass}} uses the same modeling strategy as \code{polymars},
but uses a logistic (polychotomous) likelihood.}

\references{Charles Kooperberg, Smarajit Bose, and  Charles J. Stone (1997).
Polychotomous regression. \emph{Journal of the American Statistical
Association}, \bold{92}, 117--127.

Friedman, J. H. (1991). Multivariate adaptive regression splines 
(with discussion).  \emph{The Annals of Statistics}, \bold{19}, 1--141.

Charles J. Stone, Mark Hansen, Charles Kooperberg, and Young K. Truong.
The use of polynomial splines and their tensor products in extended
linear modeling (with discussion) (1997).  \emph{Annals of Statistics},
\bold{25}, 1371--1470.}
\author{Martin O'Connor.}
\seealso{
\code{\link{polyclass}},
\code{\link{plot.polymars}},
\code{\link{predict.polymars}},
\code{\link{summary.polymars}}.}
\examples{
data(state)
state.pm <- polymars(state.region, state.x77, knots = 15, classify = TRUE)
state.pm2 <- polymars(state.x77[, 2], state.x77[,-2], gcv = 2)
plot(fitted(state.pm2), residuals(state.pm2))
}
\keyword{smooth}
\keyword{nonlinear}

\eof
\name{predict.polymars}
\alias{predict.polymars}
\title{Polymars: multivariate adaptive polynomial spline regression}
\description{Produces fitted values for a model of class \code{polymars}.}
\usage{predict.polymars(object, x, classify = FALSE, intercept, ...) }
\arguments{
\item{object}{
object of the class \code{polymars}, typically the result of \code{\link{polymars}}.}
\item{x}{
the predictor values at which the fitted values will be computed.  The 
predictor values can be in a number of formats. It can take the form of a 
vector of length equal to the number of predictors in the original data set 
or it can be shortened to the length of only those predictors that occur in 
the model, in the same order as they appear in the original data set.  
Similarly, \code{x} can take the form of a matrix with the number of columns equal to 
the number of predictors in the original data set, or shortened to the 
number of predictors in the model. 
}
\item{classify}{
if the original call to polymars was for a classification problem and you would 
like the classifications (class predictions), set this option equal to \code{TRUE}. Otherwise the 
function returns a response column for each class (the highest values in each 
row is its class for the case when \code{classify = TRUE}).  }
\item{intercept}{
 Setting intercept equal to \code{FALSE} evaluates the object without intercept. The  
intercept may also be given any numerical value which overrides the fitted  
coefficient from the object. The defualt is  \code{TRUE}.
}
\item{...}{other arguments are ignored.}
}
\value{A matrix of fitted values.
The number of columns in the 
returned matrix equals the number of responses in the original call to \code{\link{polymars}}.}
\references{ Charles Kooperberg, Smarajit Bose, and  Charles J. Stone (1997).
Polychotomous regression. \emph{Journal of the American Statistical
Association}, \bold{92}, 117--127.

Charles J. Stone, Mark Hansen, Charles Kooperberg, and Young K. Truong.
The use of polynomial splines and their tensor products in extended
linear modeling (with discussion) (1997).  \emph{Annals of Statistics},
\bold{25}, 1371--1470.}
\author{ Martin O'Connor.}
\seealso{
\code{\link{polymars}},
\code{\link{plot.polymars}},
\code{\link{summary.polymars}}.}
\examples{
data(state)
state.pm <- polymars(state.region, state.x77, knots = 15, classify = TRUE, gcv = 1)
table(predict(state.pm, x = state.x77, classify = TRUE), state.region)
}
\keyword{smooth}
\keyword{nonlinear}

\eof
\name{summary.hare}
\alias{summary.hare}
\alias{print.hare}
\title{Hare: hazard regression}
\description{This function summarizes both the stepwise selection process of the
model fitting by \code{\link{hare}}, as well as the final model
that was selected using AIC/BIC.}
\usage{summary.hare(object, ...) 
print.hare(x, ...) }
\arguments{
\item{object,x}{ \code{hare} object, typically the result of \code{\link{hare}}.  }
\item{...}{other arguments are ignored.}
}
\details{These function produce identical printed output. The main body consists of 
two tables. 

The first table has six columns: the first column is a 
possible number of dimensions for the fitted model; 

the second column indicates whether this model was fitted during 
the addition or deletion stage; 

the third column is the log-likelihood for the fit; 

the fourth column is \code{-2 * loglikelihood + penalty * (dimension)}, 
which is the AIC criterion - \code{hare} selected the model with 
the minimum value of AIC;  

the last two columns give the 
endpoints of the interval of values of penalty that would yield the 
model with the indicated number of dimensions  
(\code{NA}s imply that the model is not optimal for any choice of penalty). 

At the bottom of the first table the 
dimension of the selected model is reported, as is 
the value of penalty that was used. 

Each row of the second table summarizes the information about  
a basis function in 
the final model. It shows the variables involved, the knot locations, the 
estimated coefficient and its standard error and Wald statistic (estimate/SE). 
}
\note{
Since the basis functions are selected in an adaptive fashion, typically
most Wald statistics are larger than (the magical) 2. These statistics
should be taken with a grain of salt though, as they are inflated because
of the adaptivity of the model selection.}
\references{Charles Kooperberg, Charles J. Stone and Young K. Truong (1995).
Hazard regression.  \emph{Journal of the American Statistical
Association}, \bold{90}, 78-94.

Charles J. Stone, Mark Hansen, Charles Kooperberg, and Young K. Truong.
The use of polynomial splines and their tensor products in extended
linear modeling (with discussion) (1997).  \emph{Annals of Statistics},
\bold{25}, 1371--1470.}
\seealso{\code{\link{hare}},
\code{\link{plot.hare}},
\code{\link{dhare}},
\code{\link{hhare}},
\code{\link{phare}},
\code{\link{qhare}},
\code{\link{rhare}}.}
\author{ Charles Kooperberg \email{clk@fhcrc.org}.}
\examples{
fit <- hare(testhare[,1], testhare[,2], testhare[,3:8]) 
summary(fit) 
}
\keyword{distribution}
\keyword{smooth}
\keyword{survival}

\eof
\name{summary.heft}
\alias{summary.heft}
\alias{print.heft}
\title{Heft: hazard estimation with flexible tails}
\description{This function summarizes both the stepwise selection process of the
model fitting by \code{\link{heft}}, as well as the final model
that was selected using AIC/BIC.}
\usage{summary.heft(object, ...) 
print.heft(x, ...) }
\arguments{
\item{object,x}{ \code{heft} object, typically the result of \code{\link{heft}}.  }
\item{...}{other arguments are ignored.}
}
\details{These function produce identical printed output. The main body 
is a table with six columns: 

the first column is a possible number 
of knots for the fitted model; 

the second column is 0 if the model was fitted during the 
addition stage and 1 if the model was fitted during the deletion stage; 

the third column is the log-likelihood for the fit; 

the fourth column is \code{-2 * loglikelihood + penalty * (dimension)},
which is the AIC criterion - \code{heft} selected the model with
the minimum value of AIC;

the fifth and sixth columns give the 
endpoints of the interval of values of penalty that would yield the 
model with the indicated number of knots. (\code{NA}s imply that the model is 
not optimal for any choice of penalty.)  

At the bottom of the table the 
number of knots corresponding to the selected model is reported, as are 
the value of penalty that was used and the coefficients of the log-based 
terms in the fitted model and their standard errors. 
}
\references{Charles Kooperberg, Charles J. Stone and Young K. Truong (1995).
Hazard regression.  \emph{Journal of the American Statistical
Association}, \bold{90}, 78-94.

Charles J. Stone, Mark Hansen, Charles Kooperberg, and Young K. Truong.
The use of polynomial splines and their tensor products in extended
linear modeling (with discussion) (1997).  \emph{Annals of Statistics},
\bold{25}, 1371--1470.}
\author{ Charles Kooperberg \email{clk@fhcrc.org}.}
\seealso{
\code{\link{heft}},
\code{\link{plot.heft}},
\code{\link{dheft}},
\code{\link{hheft}},
\code{\link{pheft}},
\code{\link{qheft}},
\code{\link{rheft}}.}
\examples{
fit1 <- heft(testhare[,1], testhare[,2])
summary(fit1)
# modify tail behavior
fit2 <- heft(testhare[,1], testhare[,2], leftlog = FALSE, rightlog = FALSE, 
    leftlin = TRUE)   
summary(fit2)
fit3 <- heft(testhare[,1], testhare[,2], penalty = 0)   # select largest model
summary(fit3)
}
\keyword{distribution}
\keyword{smooth}
\keyword{survival}

\eof
\name{summary.logspline}
\alias{summary.logspline}
\alias{print.logspline}
\title{Logspline Density Estimation }
\description{ This function summarizes both the stepwise selection process of the
model fitting by \code{\link{logspline}}, as well as the final model
that was selected using AIC/BIC. A
 \code{logspline} object was fit using the 1997 knot addition and deletion algorithm.
The 1992 algorithm is available using the \code{\link{oldlogspline}} function.  }
\usage{summary.logspline(object, ...) 
print.logspline(x, ...) }
\arguments{
\item{object,x}{\code{logspline} object, typically the result of \code{\link{logspline}}}
\item{...}{ other arguments are ignored.}
}
\details{These function produce identical printed output. The main body 
is a table with five columns: the first column is a possible number 
of knots for the fitted model; 

the second column is the log-likelihood for the fit; 

the third column is \code{-2 * loglikelihood + penalty * (number of knots - 1)}, 
which is the AIC criterion; \code{\link{logspline}} selected the model with 
the smallest value of AIC; 

the fourth and fifth columns give the 
endpoints of the interval of values of penalty that would yield the 
model with the indicated number of knots. (\code{NA}s imply that the model is 
not optimal for any choice of \code{penalty}.) At the bottom of the table the 
number of knots corresponding to the selected model is reported, as is 
the value of penalty that was used. 
}
\references{Charles Kooperberg and Charles J. Stone.  Logspline density estimation
for censored data (1992). \emph{Journal of Computational and Graphical
Statistics}, \bold{1}, 301--328.

Charles J. Stone, Mark Hansen, Charles Kooperberg, and Young K. Truong.
The use of polynomial splines and their tensor products in extended
linear modeling (with discussion) (1997).  \emph{Annals of Statistics},
\bold{25}, 1371--1470.}
\author{ Charles Kooperberg \email{clk@fhcrc.org}.}
\seealso{ 
\code{\link{logspline}},      
\code{\link{plot.logspline}},
\code{\link{dlogspline}},
\code{\link{plogspline}},
\code{\link{qlogspline}},
\code{\link{rlogspline}},\cr
\code{\link{oldlogspline}}.}
\examples{
y <- rnorm(100)
fit <- logspline(y)       
summary(fit) 
}
\keyword{distribution}
\keyword{smooth}

\eof
\name{summary.lspec}
\alias{summary.lspec}
\alias{print.lspec}
\title{Lspec: logspline estimation of a spectral distribution}
\description{Summary of a model fitted with \code{\link{lspec}} }
\usage{summary.lspec(object, ...) 
 print.lspec(x, ...) }
\arguments{ \item{object,x}{ \code{lspec} object, typically the result of \code{\link{lspec}}.}
\item{...}{other options are ignored.}}
\details{These function produce an identical printed summary of an \code{lspec} object.}
\references{
Charles Kooperberg, Charles J. Stone, and Young K. Truong (1995).
Logspline Estimation of a Possibly Mixed Spectral Distribution.
\emph{Journal of Time Series Analysis}, \bold{16}, 359-388.

Charles J. Stone, Mark Hansen, Charles Kooperberg, and Young K. Truong.
The use of polynomial splines and their tensor products in extended
linear modeling (with discussion) (1997).  \emph{Annals of Statistics},
\bold{25}, 1371--1470.}
\author{ Charles Kooperberg \email{clk@fhcrc.org}.}
\seealso{\link{lspec}, \link{plot.lspec}, \link{clspec}, \link{dlspec},
\link{plspec}, \link{rlspec}.}
\examples{
data(co2)
co2.detrend <- lm(co2~c(1:length(co2)))$residuals
fit <- lspec(co2.detrend)
summary(fit)
}
\keyword{ts}
\keyword{smooth}

\eof
\name{summary.oldlogspline}
\alias{summary.oldlogspline}
\alias{print.oldlogspline}
\title{ Logspline Density Estimation - 1992 version }
\description{ This function summarizes both the stepwise selection process of the
model fitting by \code{\link{oldlogspline}}, as well as the final model
that was selected using AIC/BIC. A
 \code{logspline} object was fit using
the 1992 knot deletion algorithm (\code{\link{oldlogspline}}). 
The 1997 algorithm using knot
deletion and addition is available using the \code{\link{logspline}} function.
}
\usage{summary.oldlogspline(object, ...) 
print.oldlogspline(x, ...)}
\arguments{
\item{object,x}{
code{oldlogspline} object, typically the result of \code{\link{oldlogspline}}
}
\item{...}{ other arguments are ignored.}
}
\details{
These function produces the same printed output. The main body 
is a table with five columns: the first column is a possible number 
of knots for the fitted model; 

the second column is the log-likelihood for the fit; 

the third column is \code{-2 * loglikelihood + penalty * (number of knots - 1)},
which is the AIC criterion; \code{\link{logspline}} selected the model with
the smallest value of AIC;


the fourth and fifth columns give the 
endpoints of the interval of values of penalty that would yield the 
model with the indicated number of knots. (\code{NA}s imply that the model is 
not optimal for any choice of \code{penalty}.) At the bottom of the table the 
number of knots corresponding to the selected model is reported, as is 
the value of penalty that was used. 
}
\references{Charles Kooperberg and Charles J. Stone.  Logspline density estimation
for censored data (1992). \emph{Journal of Computational and Graphical
Statistics}, \bold{1}, 301--328.

Charles J. Stone, Mark Hansen, Charles Kooperberg, and Young K. Truong.
The use of polynomial splines and their tensor products in extended
linear modeling (with discussion) (1997).  \emph{Annals of Statistics},
\bold{25}, 1371--1470.}
\author{ Charles Kooperberg \email{clk@fhcrc.org}.}
\seealso{
\code{\link{logspline}},
\code{\link{oldlogspline}},
\code{\link{plot.oldlogspline}},
\code{\link{doldlogspline}},
\code{\link{poldlogspline}},\cr
\code{\link{qoldlogspline}},
\code{\link{roldlogspline}}.}
\examples{
y <- rnorm(100)
fit <- oldlogspline(y)       
summary(fit) 
}
\keyword{distribution}
\keyword{smooth}

\eof
\name{summary.polyclass}
\alias{summary.polyclass}
\alias{print.polyclass}
\title{Polyclass: polychotomous regression and multiple classification}
\description{This function summarizes both the stepwise selection process of the
model fitting by \code{\link{polyclass}}, as well as the final model
that was selected}
\usage{summary.polyclass(object, ...) 
print.polyclass(x, ...) }
\arguments{
\item{object,x}{  \code{polyclass} object, typically the result of \code{\link{polyclass}}.  }
\item{...}{other arguments are ignored.}
}
\value{These function summarize a \code{polyclass} fit identically. They also give information 
about fits that could have been obtained with other  
model selection options in \code{\link{polyclass}}. 
}
\references{ Charles Kooperberg, Smarajit Bose, and  Charles J. Stone (1997).
Polychotomous regression. \emph{Journal of the American Statistical
Association}, \bold{92}, 117--127.

Charles J. Stone, Mark Hansen, Charles Kooperberg, and Young K. Truong.
The use of polynomial splines and their tensor products in extended
linear modeling (with discussion) (1997).  \emph{Annals of Statistics},
\bold{25}, 1371--1470.}
\author{ Charles Kooperberg \email{clk@fhcrc.org}.}
\seealso{
\code{\link{polyclass}},
\code{\link{plot.polyclass}},
\code{\link{beta.polyclass}},
\code{\link{cpolyclass}},
\code{\link{ppolyclass}},
\code{\link{rpolyclass}}.}
\examples{
data(iris)
fit.iris <- polyclass(iris[,5], iris[,1:4])
summary(fit.iris)
}
\keyword{smooth}
\keyword{nonlinear}

\eof
\name{summary.polymars}
\alias{summary.polymars}
\alias{print.polymars}
\title{Polymars: multivariate adaptive polynomial spline regression}
\description{ Gives details of a \code{polymars} object.}
\usage{summary.polymars(object, ...) 
print.polymars(x, ...) }
\arguments{
\item{object,x}{ object of the class \code{polymars}, typically the result of \code{\link{polymars}}.}
\item{...}{other arguments are ignored.}
}
}
\details{
These two functions provide identical printed information.
about the fitting steps and the model 
selected. The first data frame contains a row for each step of the fitting 
procedure. In the columns are: a 1 for an addition step or a 0 for a deletion 
step, the size of the model at each step, residual sums of squares (RSS) and  
the generalized cross validation value (GCV), testset residual sums of squares 
or testset misclassification, whatever was used for the model selection. 
The second data frame, model, contains a row for each basis function of the 
model. Each row corresponds to one basis 
function (with two possible components). The pred1 column contains the indices 
of the first predictor of the basis function. Column knot1 is a possible knot  
in this predictor. If this column is NA, the first component is linear. If  
any of the basis functions of the model is categorical then there will be a  
level1 column. Column pred2 is the possible second predictor involved (if  
it is NA the basis function only depends on one  
predictor). Column knot2 contains the possible knot for the predictor pred2,  
and it is NA when this component is linear. This is a similar format  
to the startmodel argument together with an additional first row corresponding to the  
intercept but the startmodel doesn't use a separate column to specify levels of a  
categorical variable . If any predictor in pred2 is categorical then there will be a level2  
column. The column "coefs" (more than one column in the case of multiple response  
regression) contains the coefficients. 
}
\references{ Charles Kooperberg, Smarajit Bose, and  Charles J. Stone (1997).
Polychotomous regression. \emph{Journal of the American Statistical
Association}, \bold{92}, 117--127.

Charles J. Stone, Mark Hansen, Charles Kooperberg, and Young K. Truong.
The use of polynomial splines and their tensor products in extended
linear modeling (with discussion) (1997).  \emph{Annals of Statistics},
\bold{25}, 1371--1470.}
\author{Martin O'Connor.}
\seealso{
\code{\link{polymars}},
\code{\link{plot.polymars}},
\code{\link{predict.polymars}}.}
\examples{
data(state)
state.pm <- polymars(state.region, state.x77, knots = 15, classify = TRUE)
summary(state.pm)
}
\keyword{smooth}
\keyword{nonlinear}

\eof
\name{testhare}
\alias{testhare}
\title{Fake survival data for Hare and Heft}
\description{Fake survival analysis data set for testing \code{\link{hare}} and \code{\link{heft}}}
\usage{testhare}
\format{
A matrix with 2000 lines (observations) and 8 columns. Column 1 is
intended to be the survival time, column 2 the censoring indicator, and
columns 3 through 8 are predictors (covariates).}
\source{I started out with a real data set; then I sampled, transformed and added noise.
Virtually no number is unchanged.}
\references{Charles Kooperberg, Charles J. Stone and Young K. Truong (1995).
Hazard regression.  \emph{Journal of the American Statistical
Association}, \bold{90}, 78-94.

Charles J. Stone, Mark Hansen, Charles Kooperberg, and Young K. Truong.
The use of polynomial splines and their tensor products in extended
linear modeling (with discussion) (1997).  \emph{Annals of Statistics},
\bold{25}, 1371--1470.}
\author{ Charles Kooperberg \email{clk@fhcrc.org}.}
\seealso{ \code{\link{hare}}, \code{\link{heft}}.}
}
\examples{
harefit <- hare(testhare[,1], testhare[,2], testhare[,3:8]) 
heftfit <- heft(testhare[,1], testhare[,2])
}
\keyword{survival}
\keyword{datasets}

\eof
\name{unstrip}
\alias{unstrip}
\title{Reformat data as vector or matrix}
\description{This function tries to convert a date.frame or a matrix to a no-frills matrix without labels,
and a vector or time-series to a no-frills vector without labels.}
\usage{unstrip(x) }
\arguments{ \item{x}{ one- or two-dimensional object.} }
\value{If \code{x} is two-dimensional a  matrix
without names, if \code{x} is one-dimensional  a numerical vector}
\details{Many of the functions for \code{\link{logspline}}, \code{\link{oldlogspline}}, 
\code{\link{lspec}}, \code{\link{polyclass}},
\code{\link{hare}}, \code{\link{heft}}, and \code{\link{polymars}} were written in the ``before data.frame'' era;
\code{unstrip} attempts to keep all these functions useful with more advanced input objects.
In particular, many of these functions call \code{unstrip} before doing anything else.}
\author{ Charles Kooperberg \email{clk@fhcrc.org}.}
\examples{
data(co2)
unstrip(co2)
data(iris)
unstrip(iris)
}
\keyword{utilities}
\keyword{classes}

\eof
\name{xhare}
\alias{xhare}
\title{Hare: hazard regression}
\description{Driver function for \code{\link{dhare}}, \code{\link{hhare}}, \code{\link{phare}}, \code{\link{qhare}},
and \code{\link{rhare}}. This function is not intended for use by itself.}
\usage{xhare(arg1, arg2, arg3, arg4) }
\arguments{
\item{arg1,arg2,arg3,arg4}{ arguments.  }
}
\details{ This function is used internally.  }
\note{This function is not intended for direct use.}
\references{Charles Kooperberg, Charles J. Stone and Young K. Truong (1995).
Hazard regression.  \emph{Journal of the American Statistical
Association}, \bold{90}, 78-94.

Charles J. Stone, Mark Hansen, Charles Kooperberg, and Young K. Truong.
The use of polynomial splines and their tensor products in extended
linear modeling (with discussion) (1997).  \emph{Annals of Statistics},
\bold{25}, 1371--1470.}
\author{ Charles Kooperberg \email{clk@fhcrc.org}.}
\seealso{ \code{\link{hare}},
\code{\link{dhare}}, \code{\link{hhare}}, \code{\link{phare}}, \code{\link{qhare}},
\code{\link{rhare}}.}
\keyword{distribution}
\keyword{smooth}
\keyword{survival}

\eof
